"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../style/StyleSheet"));
var _utils = require("../utils");
var _css = _interopRequireDefault(require("../style/css"));
var _TextStyleContext = _interopRequireDefault(require("../style/TextStyleContext"));
var _View = _interopRequireDefault(require("./View"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DIRECTIONS = ['up', 'down', 'start', 'end'];
const propTypes = {
  color: _propTypes.default.string,
  direction: _propTypes.default.oneOf(DIRECTIONS),
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any
};
const getColor = context => {
  if (context && context.style) {
    const flattenedStyle = _reactNative.StyleSheet.flatten(context.style);
    if (flattenedStyle.color) {
      return flattenedStyle.color;
    }
  }
  return _StyleSheet.default.value('body-color');
};
const getBorderColorStyle = (color, direction) => {
  switch (direction) {
    case 'down':
      return {
        borderTopColor: color
      };
    case 'up':
      return {
        borderBottomColor: color
      };
    case 'end':
      return _reactNative.I18nManager.isRTL ? {
        borderRightColor: color
      } : {
        borderLeftColor: color
      };
    case 'start':
      return _reactNative.I18nManager.isRTL ? {
        borderLeftColor: color
      } : {
        borderRightColor: color
      };
    default:
      throw new Error('Unknown direction.');
  }
};
const styles = _StyleSheet.default.create({
  caret: (0, _css.default)`
    // &::after styles
    // display: inline-block;
    margin-left: $caret-spacing;
    // vertical-align: $caret-vertical-align;
    align-self: center; // added for bootstrap-rn
    // content: "";
  `,
  'caret-down': (0, _css.default)`
    // &::after styles
    border-top-width: $caret-width;
    border-right-width: $caret-width;
    border-right-color: transparent;
    border-bottom-width: 0;
    border-left-width: $caret-width;
    border-left-color: transparent;
  `,
  'caret-up': (0, _css.default)`
    // &::after styles
    border-top-width: 0;
    border-right-width: $caret-width;
    border-right-color: transparent;
    border-bottom-width: $caret-width;
    border-left-width: $caret-width;
    border-left-color: transparent;
  `,
  'caret-end': (0, _css.default)`
    // &::after styles
    border-top-width: $caret-width;
    border-top-color: transparent;
    border-right-width: 0;
    border-bottom-width: $caret-width;
    border-bottom-color: transparent;
    border-left-width: $caret-width;
  `,
  'caret-start': (0, _css.default)`
    // &::after styles
    // display: none;

    // &::before styles
    // display: inline-block;
    margin-left: 0; // added for bootstrap-rn
    margin-right: $caret-spacing;
    // vertical-align: $vertical-align;
    // content: "";
    border-top-width: $caret-width;
    border-top-color: transparent;
    border-right-width: $caret-width;
    border-bottom-width: $caret-width;
    border-bottom-color: transparent;
  `
});
const Caret = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    color,
    direction = 'down',
    style,
    ...elementProps
  } = props;
  const context = (0, _react.useContext)(_TextStyleContext.default);
  const classes = (0, _utils.getStyles)(styles, ['caret', `caret-${direction}`]);
  return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: ref,
    style: [classes, getBorderColorStyle(color || getColor(context), direction), style]
  }));
});
Caret.displayName = 'Caret';
Caret.propTypes = propTypes;
var _default = exports.default = Caret;
//# sourceMappingURL=Caret.js.map