"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../style/StyleSheet"));
var _css = _interopRequireDefault(require("../style/css"));
var _Text = _interopRequireDefault(require("./Text"));
var _utils = require("../utils");
var _useModifier = _interopRequireDefault(require("../hooks/useModifier"));
var _useAction = _interopRequireDefault(require("../hooks/useAction"));
var _useMedia = _interopRequireDefault(require("../hooks/useMedia"));
var _useStyle = _interopRequireDefault(require("../hooks/useStyle"));
var _useInteractionState = _interopRequireDefault(require("../hooks/useInteractionState"));
var _Pressable = require("./Pressable");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node.isRequired,
  onMouseEnter: _propTypes.default.func,
  onMouseLeave: _propTypes.default.func,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  link: (0, _css.default)`
    color: $link-color;
    text-decoration-color: $link-color; // added for bootstrap-rn
    text-decoration-line: $link-decoration;

    &:hover {
      color: $link-hover-color;
      text-decoration-color: $link-hover-color; // added for bootstrap-rn
      text-decoration-line: $link-hover-decoration;
    }
  `
});
const Link = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = (0, _useModifier.default)('useActionable', props, ref);
  const [actionProps, actionRef] = (0, _useAction.default)(modifierProps, modifierRef);
  const {
    children,
    // Filter hover handlers, because Text component does not have hover
    // handlers. Instead we use mouse enter/leave handlers.
    onHoverIn,
    onHoverOut,
    onMouseEnter: handleMouseEnter = () => {},
    onMouseLeave: handleMouseLeave = () => {},
    style,
    ...elementProps
  } = actionProps;
  const media = (0, _useMedia.default)();
  const classes = (0, _utils.getStyles)(styles, ['link']);
  const resolveStyle = (0, _useStyle.default)([classes, style]);
  const {
    interaction,
    interactionProps: {
      onHoverIn: handleMouseEnterInteraction,
      onHoverOut: handleMouseLeaveInteraction,
      ...interactionProps
    }
  } = (0, _useInteractionState.default)(elementProps);
  return /*#__PURE__*/_react.default.createElement(_Text.default, _extends({}, elementProps, interactionProps, {
    onMouseEnter: event => {
      handleMouseEnter(event);
      handleMouseEnterInteraction(event);
    },
    onMouseLeave: event => {
      handleMouseLeave(event);
      handleMouseLeaveInteraction(event);
    },
    ref: actionRef,
    role: (0, _Pressable.getRole)(actionProps),
    accessible: true,
    style: resolveStyle({
      media,
      interaction
    })
  }), children);
});
Link.displayName = 'Link';
Link.propTypes = propTypes;
var _default = exports.default = Link;
//# sourceMappingURL=Link.js.map