"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRole = exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactNative = require("react-native");
var _TextStyleContext = _interopRequireDefault(require("../style/TextStyleContext"));
var _useModifier = _interopRequireDefault(require("../hooks/useModifier"));
var _useAction = _interopRequireDefault(require("../hooks/useAction"));
var _useMedia = _interopRequireDefault(require("../hooks/useMedia"));
var _useStyle = _interopRequireDefault(require("../hooks/useStyle"));
var _useInteractionState = _interopRequireDefault(require("../hooks/useInteractionState"));
var _Caret = _interopRequireDefault(require("./Caret"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const DIRECTIONS = ['up', 'down', 'start', 'end'];
const propTypes = {
  children: _propTypes.default.node,
  caret: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.shape({
    direction: _propTypes.default.oneOf(DIRECTIONS),
    color: _propTypes.default.string
  })]),
  active: _propTypes.default.bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: _propTypes.default.any
};

// One of the following should be set for aria support:
// 1) role
// 2) aria-label + aria-hint
// 3) accessibilityActions + onAccessibilityAction
const getRole = props => {
  const {
    role,
    accessibilityActions
  } = props;
  if (role) {
    return role;
  }
  if (props['aria-label'] || accessibilityActions) {
    return null;
  }
  return 'button';
};
exports.getRole = getRole;
const applyCaret = (children, caret) => {
  if (!caret) {
    return children;
  }
  const options = caret === true ? {} : caret;
  const element = /*#__PURE__*/_react.default.createElement(_Caret.default, {
    color: options.color,
    direction: options.direction
  });
  const space = /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, " ");
  const isLeftCaret = options.direction === (_reactNative.I18nManager.isRTL ? 'end' : 'start');
  if (isLeftCaret) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, element, space, children);
  }
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children, space, element);
};
const Pressable = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = (0, _useModifier.default)('useActionable', props, ref);
  const [actionProps, actionRef] = (0, _useAction.default)(modifierProps, modifierRef);
  const {
    children,
    caret = false,
    active = false,
    style,
    activeStyle,
    textStyle,
    activeTextStyle,
    styleName,
    ...elementProps
  } = actionProps;
  const media = (0, _useMedia.default)();
  const context = (0, _react.useContext)(_TextStyleContext.default);
  const resolveStyle = (0, _useStyle.default)(style, styleName);
  const resolveActiveStyle = (0, _useStyle.default)(active && activeStyle);
  const resolveTextStyle = (0, _useStyle.default)([context && context.style, textStyle]);
  const resolveActiveTextStyle = (0, _useStyle.default)(active && activeTextStyle);
  const {
    interaction,
    interactionProps
  } = (0, _useInteractionState.default)(elementProps);
  const hasTextStyle = context && context.style || textStyle;
  const wrappedChildren = applyCaret(children, caret);
  return /*#__PURE__*/_react.default.createElement(_reactNative.Pressable, _extends({}, elementProps, interactionProps, {
    ref: actionRef,
    role: getRole(actionProps),
    style: [resolveStyle({
      media,
      interaction
    }), resolveActiveStyle({
      media,
      interaction
    })]
  }), hasTextStyle ? /*#__PURE__*/_react.default.createElement(_TextStyleContext.default.Provider, {
    value: {
      style: [resolveTextStyle({
        media,
        interaction
      }), resolveActiveTextStyle({
        media,
        interaction
      })],
      hasAncestor: context && context.hasTextAncestor
    }
  }, wrappedChildren) : wrappedChildren);
});
Pressable.displayName = 'Pressable';
Pressable.propTypes = propTypes;
var _default = exports.default = Pressable;
//# sourceMappingURL=Pressable.js.map