"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _tinyInvariant = _interopRequireDefault(require("tiny-invariant"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Pressable = _interopRequireDefault(require("../Pressable"));
var _utils = require("../../utils");
var _proxies = require("../../theme/proxies");
var _functions = require("../../theme/functions");
var _ButtonGroupContext = _interopRequireDefault(require("../button-group/ButtonGroupContext"));
var _useToggleButton = _interopRequireDefault(require("./useToggleButton"));
var _ListContext = _interopRequireDefault(require("../helpers/ListContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node.isRequired,
  color: _propTypes.default.oneOf([...Object.keys(_proxies.THEME_COLORS), 'link']),
  size: _propTypes.default.oneOf(['lg', 'sm']),
  outline: _propTypes.default.bool,
  active: _propTypes.default.bool,
  disabled: _propTypes.default.bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.btn': (0, _css.default)`
    flex-direction: row; // added for bootstrap-rn
    justify-content: center; // added for bootstrap-rn
    // display: inline-block;
    @include platform(web) {
      // cursor: if($enable-button-pointers, pointer, null);
      user-select: none;
    }
    background-color: transparent;
    border: $btn-border-width solid transparent;
    padding: $btn-padding-y $btn-padding-x;
    // Manually declare to provide an override to the browser default
    border-radius: $btn-border-radius;
    // @include transition($btn-transition);

    &:focus-visible {
      // outline: 0;
      // box-shadow: $btn-focus-box-shadow;
    }

    &:active {
      // @include box-shadow($btn-active-box-shadow);

      &:focus-visible {
        // @include box-shadow($btn-focus-box-shadow, $btn-active-box-shadow);
      }
    }
  `,
  '.btn --text': (0, _css.default)`
    font-family: $btn-font-family;
    font-weight: $btn-font-weight;
    line-height: $btn-font-size * $btn-line-height;
    color: $body-color;
    text-align: center;
    text-decoration: none; // if($link-decoration == none, null, none);
    white-space: $btn-white-space;
    // vertical-align: middle;
    font-size: $btn-font-size;

    &:hover {
      color: $body-color;
      text-decoration: none; // if($link-decoration == none, null, none);
    }
  `,
  '.btn.disabled': (0, _css.default)`
    // pointer-events: none;
    opacity: $btn-disabled-opacity;
    // @include box-shadow(none);
  `,
  ...(0, _utils.each)(_proxies.THEME_COLORS, (color, value) => ({
    [`.btn-${color}`]: (0, _css.default)`
      background-color: ${value};
      border-color: ${value};
      // @include box-shadow($btn-box-shadow);

      &:hover {
        background-color: ${(0, _functions.shadeColor)(value, t => t['btn-hover-bg-shade-amount'])};
        border-color: ${(0, _functions.shadeColor)(value, t => t['btn-hover-border-shade-amount'])};
      }

      &:focus-visible {
        background-color: ${(0, _functions.shadeColor)(value, t => t['btn-hover-bg-shade-amount'])};
        border-color: ${(0, _functions.shadeColor)(value, t => t['btn-hover-border-shade-amount'])};
        /* @if $enable-shadows {
          @include box-shadow($btn-box-shadow, 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5));
        } @else {
          // Avoid using mixin so we can pass custom focus shadow properly
          box-shadow: 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5);
        } */
      }

      &:active {
        background-color: ${(0, _functions.shadeColor)(value, t => t['btn-active-bg-shade-amount'])};
        // Remove CSS gradients if they're enabled
        // background-image: if($enable-gradients, none, null);
        border-color: ${(0, _functions.shadeColor)(value, t => t['btn-active-border-shade-amount'])};
      }
    `,
    [`.btn-${color} --text`]: (0, _css.default)`
      color: ${(0, _functions.colorContrast)(value)};

      &:hover {
        color: ${(0, _functions.colorContrast)(value)};
      }

      &:focus-visible {
        color: ${(0, _functions.colorContrast)(value)};
      }

      &:active {
        color: ${(0, _functions.colorContrast)(value)};
      }
    `,
    [`.btn-${color}.active`]: (0, _css.default)`
      background-color: ${(0, _functions.shadeColor)(value, t => t['btn-active-bg-shade-amount'])};
      // Remove CSS gradients if they're enabled
      // background-image: if($enable-gradients, none, null);
      border-color: ${(0, _functions.shadeColor)(value, t => t['btn-active-border-shade-amount'])};
    `,
    [`.btn-${color}.active --text`]: (0, _css.default)`
      color: ${(0, _functions.colorContrast)(value)};
    `,
    [`.btn-${color}.disabled`]: (0, _css.default)`
      $disabled-background: ${value};
      $disabled-border: ${value};

      background-color: $disabled-background;
      // Remove CSS gradients if they're enabled
      // background-image: if($enable-gradients, none, null);
      border-color: $disabled-border;
    `,
    [`.btn-${color}.disabled --text`]: (0, _css.default)`
      $disabled-color: ${(0, _functions.colorContrast)(value)};

      color: $disabled-color;
    `,
    [`.btn-outline-${color}`]: (0, _css.default)`
      border-color: ${value};

      &:hover {
        background-color: ${value};
        border-color: ${value};
      }

      &:focus-visible {
        // box-shadow: 0 0 0 $btn-focus-width rgba($color, .5);
      }

      &:active {
        background-color: ${value};
        border-color: ${value};

        /* &:focus {
          @if $enable-shadows {
            @include box-shadow(
              $btn-active-box-shadow,
              0 0 0 $btn-focus-width rgba($color, 0.5)
            );
          } @else {
            // Avoid using mixin so we can pass custom focus shadow properly
            box-shadow: 0 0 0 $btn-focus-width rgba($color, 0.5);
          }
        } */
      }
    `,
    [`.btn-outline-${color} --text`]: (0, _css.default)`
      color: ${value};

      &:hover {
        color: ${(0, _functions.colorContrast)(value)};
      }

      &:active {
        color: ${(0, _functions.colorContrast)(value)};
      }
    `,
    [`.btn-outline-${color}.disabled`]: (0, _css.default)`
      background-color: transparent;
    `,
    [`.btn-outline-${color}.disabled --text`]: (0, _css.default)`
      color: ${value};
    `
  })),
  '.btn-link --text': (0, _css.default)`
    font-weight: $font-weight-normal;
    color: $btn-link-color;
    text-decoration-color: $btn-link-color; // added for bootstrap-rn
    text-decoration-line: $link-decoration;

    &:hover {
      color: $btn-link-hover-color;
      text-decoration-color: $btn-link-hover-color; // added for bootstrap-rn
      text-decoration-line: $link-hover-decoration;
    }

    &:focus-visible {
      text-decoration-line: $link-hover-decoration;
    }

    // No need for an active state here
  `,
  '.btn-link.disabled --text': (0, _css.default)`
    color: $btn-link-disabled-color;
  `,
  '.btn-lg': (0, _css.default)`
    padding: $btn-padding-y-lg $btn-padding-x-lg;
    // Manually declare to provide an override to the browser default
    border-radius: $btn-border-radius-lg;
  `,
  '.btn-lg --text': (0, _css.default)`
    line-height: $btn-font-size-lg * $btn-line-height;
    font-size: $btn-font-size-lg;
  `,
  '.btn-sm': (0, _css.default)`
    padding: $btn-padding-y-sm $btn-padding-x-sm;
    // Manually declare to provide an override to the browser default
    border-radius: $btn-border-radius-sm;
  `,
  '.btn-sm --text': (0, _css.default)`
    line-height: $btn-font-size-sm * $btn-line-height;
    font-size: $btn-font-size-sm;
  `,
  '.btn-group > .btn': (0, _css.default)`
    position: relative;
    // flex: 1 1 auto;

    &:hover {
      z-index: 1;
    }
    &:focus-visible {
      z-index: 1;
    }
    &:active {
      z-index: 1;
    }
  `,
  '.btn-group > .btn.active': (0, _css.default)`
    z-index: 2; // 1;
  `,
  '.btn-group > .btn:not(:first-child)': (0, _css.default)`
    margin-left: -$btn-border-width;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
  `,
  '.btn-group > .btn:not(:last-child)': (0, _css.default)`
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
  `
});
const getVariant = (color, outline) => {
  if (color === 'link') {
    return null;
  }
  if (outline) {
    return `.btn-outline-${color}`;
  }
  return `.btn-${color}`;
};
const hasSize = (size, group, value) => {
  if (size !== undefined || !group) {
    return size === value;
  }
  return group.size === value;
};
const Button = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    color = 'primary',
    size,
    outline = false,
    active = false,
    disabled = false,
    style,
    activeStyle,
    textStyle,
    activeTextStyle,
    ...elementProps
  } = props;
  (0, _tinyInvariant.default)(color !== 'link' || !outline, 'Button link variant is only available as non outline style.');
  const listItem = (0, _react.useContext)(_ListContext.default);
  const group = (0, _react.useContext)(_ButtonGroupContext.default);
  const classes = (0, _utils.getStyles)(styles, ['.btn', getVariant(color, outline), disabled && '.btn.disabled', disabled && `${getVariant(color, outline)}.disabled`, hasSize(size, group, 'lg') && '.btn-lg', hasSize(size, group, 'sm') && '.btn-sm', group && '.btn-group > .btn', group && active && '.btn-group > .btn.active', group && !listItem.first && '.btn-group > .btn:not(:first-child)', group && !listItem.last && '.btn-group > .btn:not(:last-child)']);
  const activeClasses = (0, _utils.getStyles)(styles, [`${getVariant(color, outline)}.active`]);
  const textClasses = (0, _utils.getStyles)(styles, ['.btn --text', `${getVariant(color, outline)} --text`, color === 'link' && '.btn-link --text', disabled && `${getVariant(color, outline)}.disabled --text`, disabled && color === 'link' && '.btn-link.disabled --text', hasSize(size, group, 'lg') && '.btn-lg --text', hasSize(size, group, 'sm') && '.btn-sm --text']);
  const activeTextClasses = (0, _utils.getStyles)(styles, [`${getVariant(color, outline)}.active --text`]);
  return /*#__PURE__*/_react.default.createElement(_Pressable.default, _extends({}, elementProps, {
    ref: ref,
    active: active,
    disabled: disabled,
    style: [...classes, style],
    activeStyle: [...activeClasses, activeStyle],
    textStyle: [...textClasses, textStyle],
    activeTextStyle: [...activeTextClasses, activeTextStyle]
  }), children);
});
Button.displayName = 'Button';
Button.propTypes = propTypes;
Button.useToggle = _useToggleButton.default;
var _default = exports.default = Button;
//# sourceMappingURL=Button.js.map