"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _css = _interopRequireDefault(require("../../style/css"));
var _utils = require("../../utils");
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _Pressable = _interopRequireDefault(require("../Pressable"));
var _ModalContext = _interopRequireDefault(require("../modal/ModalContext"));
var _OffcanvasContext = _interopRequireDefault(require("../offcanvas/OffcanvasContext"));
var _useMedia = _interopRequireDefault(require("../../hooks/useMedia"));
var _useStyle = _interopRequireDefault(require("../../hooks/useStyle"));
var _useInteractionState = _interopRequireDefault(require("../../hooks/useInteractionState"));
var _useBackground = _interopRequireDefault(require("../../hooks/useBackground"));
var _functions = require("../../theme/functions");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node,
  disabled: _propTypes.default.bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.btn-close': (0, _css.default)`
    // Workaround for missing box-sizing in react native.
    $additional-width: $btn-close-padding-x * 2;
    $additional-height: $btn-close-padding-y * 2;

    // box-sizing: content-box;
    width: $btn-close-width + $additional-width;
    height: $btn-close-height + $additional-height;
    padding: $btn-close-padding-y $btn-close-padding-x;
    background-color: transparent; // include transparent for button elements
    background-image: ${t => (0, _functions.escapeSvg)(t['btn-close-bg'])};
    background-position: center;
    background-size: $btn-close-width auto;
    background-repeat: no-repeat;
    border-width: 0; // for button elements
    // @include border-radius();
    opacity: $btn-close-opacity;

    &:hover {
      opacity: $btn-close-hover-opacity;
    }

    &:focus {
      // outline: 0;
      // box-shadow: $btn-close-focus-shadow;
      opacity: $btn-close-focus-opacity;
    }
  `,
  '.btn-close --text': (0, _css.default)`
    color: $btn-close-color;

    // Override <a>'s hover style
    &:hover {
      color: $btn-close-color;
      text-decoration: none;
    }
  `,
  '.btn-close.disabled': (0, _css.default)`
    // pointer-events: none;
    // user-select: none;
    opacity: $btn-close-disabled-opacity;
  `,
  // Modal styles
  '.modal-header .btn-close': (0, _css.default)`
    padding: $modal-header-padding-y * 0.5 $modal-header-padding-x * 0.5;
    margin: -0.5 * $modal-header-padding-y -0.5 * $modal-header-padding-x -0.5 *
      $modal-header-padding-y auto;

    // Workaround for missing box-sizing in react native.
    width: $btn-close-width + $modal-header-padding-x;
    height: $btn-close-height + $modal-header-padding-y;
  `,
  // Offcanvas styles
  '.offcanvas-header .btn-close': (0, _css.default)`
    padding: $offcanvas-padding-y * 0.5 $offcanvas-padding-x * 0.5;
    margin-top: -0.5 * $offcanvas-padding-y;
    margin-right: -0.5 * $offcanvas-padding-x;
    margin-bottom: -0.5 * $offcanvas-padding-y;

    // Workaround for missing box-sizing in react native.
    width: $btn-close-width + $offcanvas-padding-x;
    height: $btn-close-height + $offcanvas-padding-y;
  `
});
const CloseButton = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    disabled = false,
    style,
    textStyle,
    styleName,
    ...elementProps
  } = props;
  const media = (0, _useMedia.default)();
  const modal = (0, _react.useContext)(_ModalContext.default);
  const offcanvas = (0, _react.useContext)(_OffcanvasContext.default);
  const classes = (0, _utils.getStyles)(styles, ['.btn-close', disabled && '.btn-close.disabled',
  // Modal styles
  modal && '.modal-header .btn-close',
  // Offcanvas styles
  offcanvas && '.offcanvas-header .btn-close']);
  const textClasses = (0, _utils.getStyles)(styles, ['.btn-close --text']);
  const resolveStyle = (0, _useStyle.default)([classes, style], styleName);
  const {
    interaction,
    interactionProps
  } = (0, _useInteractionState.default)(elementProps);
  const background = (0, _useBackground.default)(resolveStyle({
    media,
    interaction
  }));
  return /*#__PURE__*/_react.default.createElement(_Pressable.default, _extends({}, elementProps, interactionProps, {
    component: _Pressable.default,
    ref: ref,
    disabled: disabled,
    style: background.style,
    textStyle: [textClasses, textStyle]
  }), background.element);
});
CloseButton.displayName = 'CloseButton';
CloseButton.propTypes = propTypes;
var _default = exports.default = CloseButton;
//# sourceMappingURL=CloseButton.js.map