"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _utils = require("../../utils");
var _useForcedContext = _interopRequireDefault(require("../../hooks/useForcedContext"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Pressable = _interopRequireDefault(require("../Pressable"));
var _DropdownContext = _interopRequireDefault(require("./DropdownContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node.isRequired,
  onPress: _propTypes.default.func,
  active: _propTypes.default.bool,
  disabled: _propTypes.default.bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.dropdown-item': (0, _css.default)`
    width: 100%;
    padding: $dropdown-item-padding-y $dropdown-item-padding-x;
    // clear: both;
    background-color: transparent;
    border: 0;

    &:hover {
      // @include gradient-bg($dropdown-link-hover-bg);
      background-color: $dropdown-link-hover-bg;
    }
    &:focus {
      // @include gradient-bg($dropdown-link-hover-bg);
      background-color: $dropdown-link-hover-bg;
    }
  `,
  '.dropdown-item --text': (0, _css.default)`
    font-weight: $font-weight-normal;
    color: $dropdown-link-color;
    // text-align: inherit;
    text-decoration: none; // if($link-decoration == none, null, none);
    // white-space: nowrap;

    &:hover {
      color: $dropdown-link-hover-color;
      text-decoration: none; // if($link-hover-decoration == underline, none, null);
    }
    &:focus {
      color: $dropdown-link-hover-color;
      text-decoration: none; // if($link-hover-decoration == underline, none, null);
    }
  `,
  '.dropdown-item.active': (0, _css.default)`
    // @include gradient-bg($dropdown-link-active-bg);
    background-color: $dropdown-link-active-bg;

    &:hover {
      background-color: $dropdown-link-active-bg;
    }
    &:focus {
      background-color: $dropdown-link-active-bg;
    }
  `,
  '.dropdown-item.active --text': (0, _css.default)`
    color: $dropdown-link-active-color;
    text-decoration: none;

    &:hover {
      color: $dropdown-link-active-color;
    }
    &:focus {
      color: $dropdown-link-active-color;
    }
  `,
  '.dropdown-item.disabled': (0, _css.default)`
    // pointer-events: none;
    background-color: transparent;
    // Remove CSS gradients if they're enabled
    // background-image: if($enable-gradients, none, null);

    &:hover {
      background-color: transparent;
    }
    &:focus {
      background-color: transparent;
    }
  `,
  '.dropdown-item.disabled --text': (0, _css.default)`
    color: $dropdown-link-disabled-color;

    &:hover {
      color: $dropdown-link-disabled-color;
    }
    &:focus {
      color: $dropdown-link-disabled-color;
    }
  `
});
const DropdownItem = props => {
  const {
    children,
    onPress: handlePress,
    active = false,
    disabled = false,
    style,
    textStyle,
    ...elementProps
  } = props;
  const dropdown = (0, _useForcedContext.default)(_DropdownContext.default);
  const classes = (0, _utils.getStyles)(styles, ['.dropdown-item', active && '.dropdown-item.active', disabled && '.dropdown-item.disabled']);
  const textClasses = (0, _utils.getStyles)(styles, ['.dropdown-item --text', active && '.dropdown-item.active --text', disabled && '.dropdown-item.disabled --text']);
  return /*#__PURE__*/_react.default.createElement(_Pressable.default, _extends({}, elementProps, {
    onPress: event => {
      if (handlePress) handlePress(event);
      if (event.defaultPrevented) {
        return;
      }
      dropdown.setVisible(false);
    },
    disabled: disabled,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
};
DropdownItem.displayName = 'DropdownItem';
DropdownItem.propTypes = propTypes;
var _default = exports.default = DropdownItem;
//# sourceMappingURL=DropdownItem.js.map