"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _overlays = require("@react-native-aria/overlays");
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Overlay = _interopRequireDefault(require("../helpers/Overlay"));
var _BackdropHandler = _interopRequireDefault(require("../helpers/BackdropHandler"));
var _View = _interopRequireDefault(require("../View"));
var _useMedia = _interopRequireDefault(require("../../hooks/useMedia"));
var _proxies = require("../../theme/proxies");
var _breakpoints = require("../../theme/breakpoints");
var _utils = require("../../utils");
var _math = require("../../style/math");
var _useForcedContext = _interopRequireDefault(require("../../hooks/useForcedContext"));
var _NavbarContext = _interopRequireDefault(require("../navbar/NavbarContext"));
var _DropdownContext = _interopRequireDefault(require("./DropdownContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const ALIGNMENT_BREAKPOINTS = [true, 'sm', 'md', 'lg', 'xl', 'xxl'];
const propTypes = {
  children: _propTypes.default.node.isRequired,
  start: _propTypes.default.oneOf(ALIGNMENT_BREAKPOINTS),
  right: _propTypes.default.oneOf(ALIGNMENT_BREAKPOINTS),
  end: _propTypes.default.oneOf(ALIGNMENT_BREAKPOINTS),
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.dropdown-menu': (0, _css.default)`
    position: absolute;
    z-index: $zindex-dropdown;
    // display: none; // none by default, but block on "open" of the menu
    min-width: $dropdown-min-width;
    padding: $dropdown-padding-y $dropdown-padding-x;
    margin: 0; // Override default margin of ul
    // list-style: none;
    background-color: $dropdown-bg;
    // background-clip: padding-box;
    border: $dropdown-border-width solid $dropdown-border-color;
    border-radius: $dropdown-border-radius;
    // @include box-shadow($dropdown-box-shadow);
  `,
  '.dropdown-menu[data-bs-popper]': (0, _css.default)`
    top: 100%;
    left: 0;
    margin-top: $dropdown-spacer;
  `,
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.dropdown-menu${(0, _breakpoints.infix)(breakpoint)}-start[data-bs-popper]`]: (0, _css.default)`
      @include media-breakpoint-up(${breakpoint}) {
        right: auto;
        left: 0;
      }
    `,
    [`.dropdown-menu${(0, _breakpoints.infix)(breakpoint)}-end[data-bs-popper]`]: (0, _css.default)`
      @include media-breakpoint-up(${breakpoint}) {
        right: 0;
        left: auto;
      }
    `
  })),
  '.dropup .dropdown-menu[data-bs-popper]': (0, _css.default)`
    top: auto;
    bottom: 100%;
    margin-top: 0;
    margin-bottom: $dropdown-spacer;
  `,
  '.dropend .dropdown-menu[data-bs-popper]': (0, _css.default)`
    top: 0;
    right: auto;
    left: 100%;
    margin-top: 0;
    margin-left: $dropdown-spacer;
  `,
  '.dropstart .dropdown-menu[data-bs-popper]': (0, _css.default)`
    top: 0;
    right: 100%;
    left: auto;
    margin-top: 0;
    margin-right: $dropdown-spacer;
  `,
  '.navbar-nav .dropdown-menu': (0, _css.default)`
    position: relative; // static;
  `,
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.navbar-expand${(0, _breakpoints.infix)((0, _breakpoints.next)(breakpoint))} .navbar-nav .dropdown-menu`]: (0, _css.default)`
      @include media-breakpoint-up(${(0, _breakpoints.next)(breakpoint)}) {
        position: absolute;
      }
    `
  })),
  '.dropdown-menu --text': (0, _css.default)`
    font-size: $dropdown-font-size;
    color: $dropdown-color;
    text-align: left; // Ensures proper alignment if parent has it changed (e.g., modal footer)
  `
});
const getAlignment = (media, center, start, end) => {
  if (center) {
    return 'center';
  }
  const alignStart = typeof start === 'boolean' ? start : media.up(start);
  const alignEnd = typeof end === 'boolean' ? end : media.up(end);
  if (!alignEnd) {
    return 'start';
  }
  if (!alignStart) {
    return 'end';
  }
  const startIndex = ALIGNMENT_BREAKPOINTS.indexOf(start);
  const endIndex = ALIGNMENT_BREAKPOINTS.indexOf(end);
  return startIndex > endIndex ? 'start' : 'end';
};
const transformPlacement = (media, direction, center, start, end) => {
  if (direction === 'up') {
    return `top ${getAlignment(media, center, start, end)}`;
  }
  if (direction === 'down') {
    return `bottom ${getAlignment(media, center, start, end)}`;
  }
  return `${direction} top`;
};
const DropdownMenu = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    start = true,
    right,
    end = false,
    style,
    textStyle,
    ...elementProps
  } = props;
  if (right !== undefined) {
    // eslint-disable-next-line no-console
    console.warn('Prop "right" is deprecated, please use "end" instead.');
  }
  const navbar = (0, _react.useContext)(_NavbarContext.default);
  const media = (0, _useMedia.default)();
  const dialogRef = (0, _react.useRef)();
  const dropdown = (0, _useForcedContext.default)(_DropdownContext.default);
  const {
    identifier,
    toggleRef,
    visible,
    setVisible,
    direction,
    center,
    display,
    autoClose
  } = dropdown;
  if (!visible) {
    return null;
  }
  const isStatic = _reactNative.Platform.OS === 'web' && display === 'static';
  const isCollapsedNavbar = navbar && !(navbar.expand && (navbar.expand === true || media.up(navbar.expand)));
  const hasStaticStyle = isStatic && !isCollapsedNavbar;
  const classes = (0, _utils.getStyles)(styles, ['.dropdown-menu',
  // Non-Popper styles
  hasStaticStyle && '.dropdown-menu[data-bs-popper]', hasStaticStyle && start && `.dropdown-menu${start === true ? '' : `-${start}`}-start[data-bs-popper]`, hasStaticStyle && end && `.dropdown-menu${end === true ? '' : `-${end}`}-end[data-bs-popper]`, hasStaticStyle && direction === 'up' && '.dropup .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'end' && '.dropend .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'start' && '.dropstart .dropdown-menu[data-bs-popper]',
  // Navbar styles
  navbar && '.navbar-nav .dropdown-menu', navbar && navbar.expand && `.navbar-expand${navbar.expand === true ? '' : `-${navbar.expand}`} .navbar-nav .dropdown-menu`]);
  const textClasses = (0, _utils.getStyles)(styles, ['.dropdown-menu --text']);
  if (isStatic || isCollapsedNavbar) {
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, !isCollapsedNavbar && /*#__PURE__*/_react.default.createElement(_BackdropHandler.default, {
      toggleRef: toggleRef,
      dialogRef: dialogRef,
      onClose: () => {
        setVisible(false);
      },
      autoClose: autoClose
    }), /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
      ref: (0, _utils.concatRefs)(dialogRef, ref),
      "aria-labelledby": identifier,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children));
  }
  return /*#__PURE__*/_react.default.createElement(_overlays.OverlayContainer, null, /*#__PURE__*/_react.default.createElement(_Overlay.default, {
    placement: transformPlacement(media, direction, center, start, end),
    targetRef: toggleRef,
    offset: (0, _math.normalizeNumber)(_StyleSheet.default.value('dropdown-spacer')),
    visible: visible
  }, (overlay, overlayRef) => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_BackdropHandler.default, {
    toggleRef: toggleRef,
    dialogRef: overlayRef,
    onClose: () => {
      setVisible(false);
    },
    autoClose: autoClose
  }), /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: (0, _utils.concatRefs)(overlayRef, ref),
    "aria-labelledby": identifier,
    style: [classes, overlay.overlayProps.style, {
      maxHeight: 'auto',
      opacity: overlay.rendered ? 1 : 0
    }, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/_react.default.createElement(_DropdownContext.default.Provider, {
    value: dropdown
  }, children)))));
});
DropdownMenu.displayName = 'DropdownMenu';
DropdownMenu.propTypes = propTypes;
var _default = exports.default = DropdownMenu;
//# sourceMappingURL=DropdownMenu.js.map