"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _View = _interopRequireDefault(require("../View"));
var _proxies = require("../../theme/proxies");
var _breakpoints = require("../../theme/breakpoints");
var _utils = require("../../utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const sizes = (0, _utils.makeArray)(_proxies.GRID_COLUMNS).map(v => v + 1);
const propTypes = {
  children: _propTypes.default.node.isRequired,
  size: _propTypes.default.oneOf(['auto', ...sizes]),
  sizeSm: _propTypes.default.oneOf(['auto', ...sizes]),
  sizeMd: _propTypes.default.oneOf(['auto', ...sizes]),
  sizeLg: _propTypes.default.oneOf(['auto', ...sizes]),
  sizeXl: _propTypes.default.oneOf(['auto', ...sizes]),
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '*': (0, _css.default)`
    // Add box sizing if only the grid is loaded
    /* box-sizing: if(
      variable-exists(include-column-box-sizing) and $include-column-box-sizing,
      border-box,
      null
    ); */
    // Prevent columns from becoming too narrow when at smaller grid tiers by
    // always setting "width: 100%;". This works because we set the width
    // later on to override this initial width.
    flex-shrink: 0;
    width: 100%;
    @include platform(web) {
      max-width: 100%; // Prevent ".col-auto", ".col" (& responsive variants) from breaking out the grid
    }
    padding-right: $grid-gutter-width * 0.5;
    padding-left: $grid-gutter-width * 0.5;
    margin-top: 0;
  `,
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.col${(0, _breakpoints.infix)(breakpoint)}`]: (0, _css.default)`
      @include media-breakpoint-up(${breakpoint}) {
        flex: 1 0 0%; // Flexbugs #4: https://github.com/philipwalton/flexbugs#flexbug-4
      }
    `,
    [`.col${(0, _breakpoints.infix)(breakpoint)}-auto`]: (0, _css.default)`
      @include media-breakpoint-up(${breakpoint}) {
        flex: 0 0 auto;
        width: auto;
      }
    `,
    ...(0, _utils.normalize)((0, _utils.makeArray)(_proxies.GRID_COLUMNS - 1, i => ({
      [`.col${(0, _breakpoints.infix)(breakpoint)}-${i + 1}`]: (0, _css.default)`
          @include media-breakpoint-up(${breakpoint}) {
            flex: 0 0 auto;
            width: ${(i + 1) / _proxies.GRID_COLUMNS * 100}%;
          }
        `,
      [`.offset${(0, _breakpoints.infix)(breakpoint)}-${i}`]: (0, _css.default)`
          @include media-breakpoint-up(${breakpoint}) {
            margin-left: ${i / _proxies.GRID_COLUMNS * 100}%;
          }
        `
    })))
  }))
});
const Col = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    size,
    sizeSm,
    sizeMd,
    sizeLg,
    sizeXl,
    style,
    ...elementProps
  } = props;
  const classes = (0, _utils.getStyles)(styles, ['*', `.col-${size.toString()}`, sizeSm && `.col-sm-${sizeSm.toString()}`, sizeMd && `.col-md-${sizeMd.toString()}`, sizeLg && `.col-lg-${sizeLg.toString()}`, sizeXl && `.col-xl-${sizeXl.toString()}`]);
  return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
Col.displayName = 'Col';
Col.propTypes = propTypes;
var _default = exports.default = Col;
//# sourceMappingURL=Col.js.map