"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Pressable = _interopRequireDefault(require("../Pressable"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const propTypes = {
  toggleRef: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.object]),
  dialogRef: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.object]),
  onClose: _propTypes.default.func,
  autoClose: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.oneOf(['inside', 'outside'])]),
  backdrop: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.oneOf(['static'])])
};
const styles = _StyleSheet.default.create({
  handler: (0, _css.default)`
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    position: absolute;
    flex-grow: 1;
  `
});
const initialState = {
  waitingForMouseUp: false,
  ignoreBackdropClick: false
};
const BackdropHandler = props => {
  const {
    toggleRef,
    dialogRef,
    onClose: handleClose,
    backdrop = true,
    autoClose = 'outside'
  } = props;
  if (_reactNative.Platform.OS === 'web') {
    const state = (0, _react.useMemo)(() => initialState, []);
    (0, _react.useEffect)(() => {
      const toggle = toggleRef ? (0, _reactNative.findNodeHandle)(toggleRef.current) : undefined;
      const dialog = (0, _reactNative.findNodeHandle)(dialogRef.current);
      const handleDialogMouseDown = () => {
        state.waitingForMouseUp = true;
      };

      // Workaround for chrome, because chrome does not fire onMouseDown event
      // for dialog when clicking on the <select> menu.
      const handleDialogMouseUp = () => {
        state.ignoreBackdropClick = true;
      };
      const handleDocumentClick = _ref => {
        let {
          target
        } = _ref;
        const isDialogClick = state.ignoreBackdropClick || dialog.contains(target);
        if (backdrop === 'static' || autoClose === false) {
          return;
        }

        // Click outside -> return if autoClose is inside.
        if (!isDialogClick && autoClose === 'inside') {
          return;
        }

        // Click inside / on dialog -> return if autoClose is outside.
        if (isDialogClick) {
          state.ignoreBackdropClick = false;
          if (autoClose === 'outside') {
            return;
          }
        }

        // Click on toggle -> return always.
        if (toggle && (target === toggle || toggle.contains(target))) {
          return;
        }
        handleClose();
      };
      const handleDocumentMouseUp = () => {
        if (state.waitingForMouseUp) {
          state.ignoreBackdropClick = true;
        }
        state.waitingForMouseUp = false;
      };
      dialog.addEventListener('mousedown', handleDialogMouseDown);
      dialog.addEventListener('mouseup', handleDialogMouseUp);
      // See https://github.com/necolas/react-native-web/issues/2115
      document.addEventListener('click', handleDocumentClick, true);
      document.addEventListener('mouseup', handleDocumentMouseUp, true);
      return () => {
        dialog.addEventListener('mousedown', handleDialogMouseDown);
        dialog.addEventListener('mouseup', handleDialogMouseUp);
        document.removeEventListener('click', handleDocumentClick, true);
        document.removeEventListener('mouseup', handleDocumentMouseUp, true);
      };
    }, [backdrop, autoClose]);
    return null;
  }
  if (backdrop !== true) {
    return null;
  }
  return /*#__PURE__*/_react.default.createElement(_Pressable.default, {
    style: styles.handler,
    onPress: () => {
      handleClose();
    },
    accessible: false,
    importantForAccessibility: "no"
  });
};
BackdropHandler.displayName = 'BackdropHandler';
BackdropHandler.propTypes = propTypes;
var _default = exports.default = BackdropHandler;
//# sourceMappingURL=BackdropHandler.js.map