"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _overlays = require("@react-native-aria/overlays");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const propTypes = {
  children: _propTypes.default.func.isRequired,
  placement: _propTypes.default.string.isRequired,
  targetRef: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.object]),
  offset: _propTypes.default.number,
  arrowOffset: _propTypes.default.number,
  visible: _propTypes.default.bool.isRequired
};
const Overlay = props => {
  const {
    children,
    targetRef,
    placement,
    offset,
    arrowOffset = 0,
    visible
  } = props;
  const overlayRef = (0, _react.useRef)();
  const overlay = (0, _overlays.useOverlayPosition)({
    placement,
    targetRef,
    overlayRef,
    offset,
    isOpen: visible
  });

  // Remove unnecessary arrow styles and adjust arrow offset.
  if (placement === 'top' || placement === 'bottom') {
    delete overlay.arrowProps.style.top;
    if (typeof overlay.arrowProps.style.left === 'number') {
      overlay.arrowProps.style.left -= arrowOffset;
    }
  }
  if (placement === 'left' || placement === 'right') {
    delete overlay.arrowProps.style.left;
    if (typeof overlay.arrowProps.style.top === 'number') {
      overlay.arrowProps.style.top -= arrowOffset;
    }
  }

  // Adjust top value by status bar height on Android
  if (_reactNative.Platform.OS === 'android' && _reactNative.StatusBar.currentHeight) {
    if (typeof overlay.overlayProps.style.top === 'number') {
      overlay.overlayProps.style.top -= _reactNative.StatusBar.currentHeight;
    }
    if (typeof overlay.arrowProps.style.top === 'number') {
      overlay.arrowProps.style.top -= _reactNative.StatusBar.currentHeight;
    }
  }
  return children(overlay, overlayRef);
};
Overlay.displayName = 'Overlay';
Overlay.propTypes = propTypes;
var _default = exports.default = Overlay;
//# sourceMappingURL=Overlay.js.map