"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.styles = exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _View = _interopRequireDefault(require("../View"));
var _utils = require("../../utils");
var _proxies = require("../../theme/proxies");
var _functions = require("../../theme/functions");
var _useForcedContext = _interopRequireDefault(require("../../hooks/useForcedContext"));
var _ListContext = _interopRequireDefault(require("../helpers/ListContext"));
var _ListGroupContext = _interopRequireDefault(require("./ListGroupContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node.isRequired,
  color: _propTypes.default.oneOf(Object.keys(_proxies.THEME_COLORS)),
  active: _propTypes.default.bool,
  disabled: _propTypes.default.bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any
};
const styles = exports.styles = _StyleSheet.default.create({
  '.list-group-item': (0, _css.default)`
    position: relative;
    // display: block;
    padding: $list-group-item-padding-y $list-group-item-padding-x;
    background-color: $list-group-bg;
    border: $list-group-border-width solid $list-group-border-color;
  `,
  '.list-group-item --text': (0, _css.default)`
    color: $list-group-color;
    text-decoration: none; // if($link-decoration == none, null, none);
  `,
  '.list-group-item:first-child': (0, _css.default)`
    border-top-left-radius: $list-group-border-radius;
    border-top-right-radius: $list-group-border-radius;
  `,
  '.list-group-item:last-child': (0, _css.default)`
    border-bottom-left-radius: $list-group-border-radius;
    border-bottom-right-radius: $list-group-border-radius;
  `,
  '.list-group-item.disabled': (0, _css.default)`
    // pointer-events: none;
    background-color: $list-group-disabled-bg;
  `,
  '.list-group-item.disabled --text': (0, _css.default)`
    color: $list-group-disabled-color;
  `,
  '.list-group-item.active': (0, _css.default)`
    z-index: 2; // Place active items above their siblings for proper border styling
    background-color: $list-group-active-bg;
    border-color: $list-group-active-border-color;
  `,
  '.list-group-item.active --text': (0, _css.default)`
    color: $list-group-active-color;
  `,
  '.list-group-item + .list-group-item': (0, _css.default)`
    border-top-width: 0;
  `,
  '.list-group-item + .list-group-item.active': (0, _css.default)`
    margin-top: -$list-group-border-width;
    border-top-width: $list-group-border-width;
  `,
  '.list-group-item-flush': (0, _css.default)`
    border-top-left-radius: 0; // added for bootstrap-rn
    border-top-right-radius: 0; // added for bootstrap-rn
    border-bottom-left-radius: 0; // added for bootstrap-rn
    border-bottom-right-radius: 0; // added for bootstrap-rn
    border-top-width: 0;
    border-right-width: 0;
    border-bottom-width: $list-group-border-width;
    border-left-width: 0;
  `,
  '.list-group-item-flush:last-child': (0, _css.default)`
    border-bottom-width: 0;
  `,
  '.list-group-item-flush + .list-group-item-flush.active': (0, _css.default)`
    border-top-width: $list-group-border-width; // added for bootstrap-rn
  `,
  ...(0, _utils.each)(_proxies.THEME_COLORS, (state, value) => ({
    [`.list-group-item-${state}`]: (0, _css.default)`
      background-color: ${(0, _functions.shiftColor)(value, t => t['list-group-item-bg-scale'])};
    `,
    [`.list-group-item-${state} --text`]: (0, _css.default)`
      color: ${(0, _functions.shiftColor)(value, t => t['list-group-item-color-scale'])};
    `
  }))
});
const ListGroupItem = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    color,
    active = false,
    disabled = false,
    style,
    textStyle,
    ...elementProps
  } = props;
  const {
    first,
    last
  } = (0, _useForcedContext.default)(_ListContext.default);
  const {
    flush
  } = (0, _useForcedContext.default)(_ListGroupContext.default);
  const classes = (0, _utils.getStyles)(styles, ['.list-group-item', first && '.list-group-item:first-child', last && '.list-group-item:last-child', active && '.list-group-item.active', disabled && '.list-group-item.disabled', !first && '.list-group-item + .list-group-item', !first && active && '.list-group-item + .list-group-item.active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush:last-child', !first && flush && active && '.list-group-item-flush + .list-group-item-flush.active', color && `.list-group-item-${color}`]);
  const textClasses = (0, _utils.getStyles)(styles, ['.list-group-item --text', active && '.list-group-item.active --text', disabled && '.list-group-item.disabled --text', color && `.list-group-item-${color} --text`]);
  const role = _reactNative.Platform.OS === 'web' ? 'listitem' : null;
  return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: ref,
    role: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
ListGroupItem.displayName = 'ListGroupItem';
ListGroupItem.propTypes = propTypes;
var _default = exports.default = ListGroupItem;
//# sourceMappingURL=ListGroupItem.js.map