"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Pressable = _interopRequireDefault(require("../Pressable"));
var _utils = require("../../utils");
var _proxies = require("../../theme/proxies");
var _functions = require("../../theme/functions");
var _useModifier = _interopRequireDefault(require("../../hooks/useModifier"));
var _useForcedContext = _interopRequireDefault(require("../../hooks/useForcedContext"));
var _ListGroupItem = require("./ListGroupItem");
var _ListContext = _interopRequireDefault(require("../helpers/ListContext"));
var _ListGroupContext = _interopRequireDefault(require("./ListGroupContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node.isRequired,
  color: _propTypes.default.oneOf(Object.keys(_proxies.THEME_COLORS)),
  active: _propTypes.default.bool,
  disabled: _propTypes.default.bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: _propTypes.default.any
};
const actionStyles = _StyleSheet.default.create({
  '.list-group-item-action': (0, _css.default)`
    width: 100%; // For "<button>"s (anchors become 100% by default though)

    // Hover state
    &:hover {
      z-index: 1; // Place hover/focus items above their siblings for proper border styling
      background-color: $list-group-hover-bg;
    }

    &:focus {
      z-index: 1; // Place hover/focus items above their siblings for proper border styling
      background-color: $list-group-hover-bg;
    }

    &:active {
      background-color: $list-group-action-active-bg;
    }
  `,
  '.list-group-item-action --text': (0, _css.default)`
    color: $list-group-action-color;
    // text-align: inherit; // For "<button>"s (anchors inherit)

    // Hover state
    &:hover {
      color: $list-group-action-hover-color;
      text-decoration: none;
    }

    &:focus {
      color: $list-group-action-hover-color;
      text-decoration: none;
    }

    &:active {
      color: $list-group-action-active-color;
    }
  `,
  ...(0, _utils.each)(_proxies.THEME_COLORS, (state, value) => ({
    [`.list-group-item-${state}-action`]: (0, _css.default)`
      &:hover {
        background-color: ${(0, _functions.shadeColor)((0, _functions.shiftColor)(value, t => t['list-group-item-bg-scale']), 0.1)};
      }

      &:focus {
        background-color: ${(0, _functions.shadeColor)((0, _functions.shiftColor)(value, t => t['list-group-item-bg-scale']), 0.1)};
      }
    `,
    [`.list-group-item-${state}-action --text`]: (0, _css.default)`
      &:hover {
        color: ${(0, _functions.shiftColor)(value, t => t['list-group-item-color-scale'])};
      }

      &:focus {
        color: ${(0, _functions.shiftColor)(value, t => t['list-group-item-color-scale'])};
      }
    `,
    [`.list-group-item-${state}-action.active`]: (0, _css.default)`
      background-color: ${(0, _functions.shiftColor)(value, t => t['list-group-item-color-scale'])};
      border-color: ${(0, _functions.shiftColor)(value, t => t['list-group-item-color-scale'])};
    `,
    [`.list-group-item-${state}-action.active --text`]: (0, _css.default)`
      color: $white;
    `
  }))
});
const ListGroupItemAction = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = (0, _useModifier.default)('useTabbable', props, ref);
  const {
    children,
    color,
    active = false,
    disabled = false,
    style,
    activeStyle,
    textStyle,
    activeTextStyle,
    ...elementProps
  } = modifierProps;
  const {
    first,
    last
  } = (0, _useForcedContext.default)(_ListContext.default);
  const {
    flush
  } = (0, _useForcedContext.default)(_ListGroupContext.default);
  const styles = {
    ..._ListGroupItem.styles,
    ...actionStyles
  };
  const classes = (0, _utils.getStyles)(styles, ['.list-group-item', '.list-group-item-action', first && '.list-group-item:first-child', last && '.list-group-item:last-child', disabled && '.list-group-item.disabled', !first && '.list-group-item + .list-group-item', !first && active && '.list-group-item + .list-group-item.active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush:last-child', !first && flush && active && '.list-group-item-flush + .list-group-item-flush.active', color && `.list-group-item-${color}`, color && `.list-group-item-${color}-action`]);
  const activeClasses = (0, _utils.getStyles)(styles, ['.list-group-item.active', color && `.list-group-item-${color}-action.active`]);
  const textClasses = (0, _utils.getStyles)(styles, ['.list-group-item --text', '.list-group-item-action --text', disabled && '.list-group-item.disabled --text', color && `.list-group-item-${color} --text`, color && `.list-group-item-${color}-action --text`]);
  const activeTextClasses = (0, _utils.getStyles)(styles, ['.list-group-item.active --text', color && `.list-group-item-${color}-action.active --text`]);
  const role = _reactNative.Platform.OS === 'web' ? 'listitem' : null;
  return /*#__PURE__*/_react.default.createElement(_Pressable.default, _extends({}, elementProps, {
    ref: modifierRef,
    role: role,
    active: active,
    disabled: disabled,
    style: [...classes, style],
    activeStyle: [...activeClasses, activeStyle],
    textStyle: [...textClasses, textStyle],
    activeTextStyle: [...activeTextClasses, activeTextStyle]
  }), children);
});
ListGroupItemAction.displayName = 'ListGroupItemAction';
ListGroupItemAction.propTypes = propTypes;
var _default = exports.default = ListGroupItemAction;
//# sourceMappingURL=ListGroupItemAction.js.map