"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _overlays = require("@react-native-aria/overlays");
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _utils = require("../../utils");
var _css = _interopRequireDefault(require("../../style/css"));
var _ScrollView = _interopRequireDefault(require("../ScrollView"));
var _View = _interopRequireDefault(require("../View"));
var _BackdropHandler = _interopRequireDefault(require("../helpers/BackdropHandler"));
var _useScrollbarEffects = _interopRequireDefault(require("../../hooks/useScrollbarEffects"));
var _useModal = _interopRequireDefault(require("./useModal"));
var _ModalContext = _interopRequireDefault(require("./ModalContext"));
var _ModalHeader = _interopRequireDefault(require("./ModalHeader"));
var _ModalTitle = _interopRequireDefault(require("./ModalTitle"));
var _ModalBody = _interopRequireDefault(require("./ModalBody"));
var _ModalFooter = _interopRequireDefault(require("./ModalFooter"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const MODAL_SIZES = ['sm', 'lg', 'xl'];
const propTypes = {
  children: _propTypes.default.node.isRequired,
  visible: _propTypes.default.bool.isRequired,
  size: _propTypes.default.oneOf(MODAL_SIZES),
  backdrop: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.oneOf(['static'])]),
  scrollable: _propTypes.default.bool,
  centered: _propTypes.default.bool,
  onToggle: _propTypes.default.func.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  contentContainerStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  contentStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogTextStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  contentTextStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.modal': (0, _css.default)`
    position: absolute; // fixed;
    top: 0;
    left: 0;
    z-index: $zindex-modal;
    // display: none;
    width: 100%;
    height: 100%;
    // overflow-x: hidden;
    // overflow-y: auto;
    // Prevent Chrome on Windows from adding a focus outline. For details, see
    // https://github.com/twbs/bootstrap/pull/10951.
    @include platform(web) {
      outline-width: 0; // outline: 0;
    }
    // We deliberately don't use "-webkit-overflow-scrolling: touch;" due to a
    // gnarly iOS Safari bug: https://bugs.webkit.org/show_bug.cgi?id=158342
    // See also https://github.com/twbs/bootstrap/issues/17695
  `,
  '.modal-dialog': (0, _css.default)`
    position: relative;
    width: auto;
    margin: $modal-dialog-margin;
    // allow clicks to pass through for custom click handling to close modal
    // pointer-events: none;

    @include media-breakpoint-up(sm) {
      width: 100%; // added for bootstrap-rn
      max-width: $modal-md;
      margin: $modal-dialog-margin-y-sm-up auto;
    }
  `,
  '.modal-dialog-scrollable': (0, _css.default)`
    flex-shrink: 1; // added for bootstrap-rn
    // height: calc(100% - var(--#{$prefix}modal-margin) * 2);
  `,
  '.modal-dialog-scrollable .modal-content': (0, _css.default)`
    max-height: 100%;
    overflow: hidden;
  `,
  '.modal-dialog-centered': (0, _css.default)`
    display: flex;
    // align-items: center;
    // min-height: calc(100% - var(--#{$prefix}modal-margin) * 2);
  `,
  '.modal-content': (0, _css.default)`
    position: relative;
    display: flex;
    flex-direction: column;
    width: 100%; // Ensure ".modal-content" extends the full width of the parent ".modal-dialog"
    // counteract the pointer-events: none; in the .modal-dialog
    // pointer-events: auto;
    background-color: $modal-content-bg;
    // background-clip: padding-box;
    border: $modal-content-border-width solid $modal-content-border-color;
    border-radius: $modal-content-border-radius;
    // @include box-shadow($modal-content-box-shadow-xs);
    // Remove focus outline from opened modal
    // outline: 0;

    @include media-breakpoint-up(sm) {
      // @include box-shadow($modal-content-box-shadow-sm-up);
    }
  `,
  '.modal-content --text': (0, _css.default)`
    color: $modal-content-color;
  `,
  '.modal-backdrop': (0, _css.default)`
    position: absolute;
    top: 0;
    left: 0;
    z-index: $zindex-modal-backdrop;
    width: 100%;
    height: 100%;
    background-color: $modal-backdrop-bg;
    opacity: $modal-backdrop-opacity;
  `,
  '.modal-sm': (0, _css.default)`
    @include media-breakpoint-up(sm) {
      max-width: $modal-sm;
    }
  `,
  '.modal-lg': (0, _css.default)`
    @include media-breakpoint-up(lg) {
      max-width: $modal-lg;
    }
  `,
  '.modal-xl': (0, _css.default)`
    @include media-breakpoint-up(lg) {
      max-width: $modal-lg;
    }
    @include media-breakpoint-up(xl) {
      max-width: $modal-xl;
    }
  `
});
const Modal = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    visible,
    size,
    backdrop = true,
    scrollable = false,
    centered = false,
    onToggle: handleToggle,
    style,
    contentContainerStyle,
    dialogStyle,
    contentStyle,
    textStyle,
    dialogTextStyle,
    contentTextStyle,
    ...elementProps
  } = props;
  const dialogRef = (0, _react.useRef)();
  const modal = (0, _useModal.default)(scrollable);
  (0, _useScrollbarEffects.default)({
    keepBodyScroll: false,
    visible
  });
  const backdropClasses = (0, _utils.getStyles)(styles, ['.modal-backdrop']);
  const classes = (0, _utils.getStyles)(styles, ['.modal']);
  const dialogClasses = (0, _utils.getStyles)(styles, ['.modal-dialog', size === 'sm' && '.modal-sm', size === 'lg' && '.modal-lg', size === 'xl' && '.modal-xl', scrollable && '.modal-dialog-scrollable', centered && '.modal-dialog-centered']);
  const contentClasses = (0, _utils.getStyles)(styles, ['.modal-content', scrollable && '.modal-dialog-scrollable .modal-content']);
  const contentTextClasses = (0, _utils.getStyles)(styles, ['.modal-content --text']);

  // If scrollable we use a ScrollView in ModalBody, so we can use a View here.
  const FlexView = scrollable ? _View.default : _ScrollView.default;
  const centeredStyle = centered && {
    justifyContent: 'center'
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    transparent: true,
    visible: visible,
    onRequestClose: handleToggle
  }, backdrop && /*#__PURE__*/_react.default.createElement(_View.default, {
    style: backdropClasses
  }), /*#__PURE__*/_react.default.createElement(FlexView, _extends({}, elementProps, {
    ref: ref,
    style: [classes, scrollable && centeredStyle, style],
    textStyle: textStyle,
    contentContainerStyle: scrollable ? undefined : [{
      flexGrow: 1
    }, centeredStyle, contentContainerStyle]
  }), /*#__PURE__*/_react.default.createElement(_BackdropHandler.default, {
    dialogRef: dialogRef,
    onClose: handleToggle,
    backdrop: backdrop
  }), /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: {
      flexShrink: 1
    }
  }, /*#__PURE__*/_react.default.createElement(_View.default, {
    ref: dialogRef,
    style: [dialogClasses, dialogStyle],
    textStyle: dialogTextStyle
  }, /*#__PURE__*/_react.default.createElement(_View.default, {
    style: [contentClasses, contentStyle],
    textStyle: [contentTextClasses, contentTextStyle]
  }, /*#__PURE__*/_react.default.createElement(_ModalContext.default.Provider, {
    value: modal
  }, /*#__PURE__*/_react.default.createElement(_overlays.OverlayProvider, null, children)))))));
});
Modal.displayName = 'Modal';
Modal.propTypes = propTypes;
Modal.Context = _ModalContext.default;
Modal.Header = _ModalHeader.default;
Modal.Title = _ModalTitle.default;
Modal.Body = _ModalBody.default;
Modal.Footer = _ModalFooter.default;
var _default = exports.default = Modal;
//# sourceMappingURL=Modal.js.map