"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _View = _interopRequireDefault(require("../View"));
var _proxies = require("../../theme/proxies");
var _breakpoints = require("../../theme/breakpoints");
var _utils = require("../../utils");
var _NavbarContext = _interopRequireDefault(require("../navbar/NavbarContext"));
var _NavContext = _interopRequireDefault(require("./NavContext"));
var _NavLink = _interopRequireDefault(require("./NavLink"));
var _TabContext = _interopRequireDefault(require("./TabContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node.isRequired,
  variant: _propTypes.default.oneOf(['tabs', 'pills']),
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.nav': (0, _css.default)`
    display: flex;
    flex-direction: row; // added for bootstrap-rn
    // flex-wrap: wrap; // bootstrap-rn: width will shrink on native with "flex-direction: column;"
    padding-left: 0;
    margin-bottom: 0;
    // list-style: none;
  `,
  '.nav-tabs': (0, _css.default)`
    border-bottom-width: $nav-tabs-border-width;
    border-style: solid;
    border-color: $nav-tabs-border-color;
  `,
  // Navbar styles
  '.navbar-nav': (0, _css.default)`
    display: flex;
    flex-direction: column; // cannot use "inherit" to get the ".navbar"s value
    padding-left: 0;
    margin-bottom: 0;
    // list-style: none;
  `,
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.navbar-expand${(0, _breakpoints.infix)((0, _breakpoints.next)(breakpoint))} .navbar-nav`]: (0, _css.default)`
      @include media-breakpoint-up(${(0, _breakpoints.next)(breakpoint)}) {
        flex-direction: row;
      }
    `
  }))
});
const getRole = (tabbable, navbar) => {
  if (tabbable) {
    return 'tablist';
  }
  if (_reactNative.Platform.OS === 'web' && !navbar) {
    return 'navigation';
  }
  return null;
};
const Nav = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    variant,
    style,
    ...elementProps
  } = props;
  const navbar = (0, _react.useContext)(_NavbarContext.default);
  const tabbable = (0, _react.useContext)(_TabContext.default);
  const classes = (0, _utils.getStyles)(styles, [!navbar && '.nav', variant === 'tabs' && '.nav-tabs',
  // Navbar styles
  navbar && '.navbar-nav', navbar && navbar.expand && `.navbar-expand${navbar.expand === true ? '' : `-${navbar.expand}`} .navbar-nav`]);
  return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: ref,
    role: getRole(tabbable, navbar),
    style: [classes, style]
  }), /*#__PURE__*/_react.default.createElement(_NavContext.default.Provider, {
    value: {
      variant
    }
  }, children));
});
Nav.displayName = 'Nav';
Nav.propTypes = propTypes;
Nav.Context = _NavContext.default;
Nav.Link = _NavLink.default;
var _default = exports.default = Nav;
//# sourceMappingURL=Nav.js.map