"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Pressable = _interopRequireDefault(require("../Pressable"));
var _View = _interopRequireDefault(require("../View"));
var _useForcedContext = _interopRequireDefault(require("../../hooks/useForcedContext"));
var _proxies = require("../../theme/proxies");
var _breakpoints = require("../../theme/breakpoints");
var _utils = require("../../utils");
var _NavbarContext = _interopRequireDefault(require("./NavbarContext"));
var _useMedia = _interopRequireDefault(require("../../hooks/useMedia"));
var _useToggleNavbar = _interopRequireDefault(require("./useToggleNavbar"));
var _useStyle = _interopRequireDefault(require("../../hooks/useStyle"));
var _useBackground = _interopRequireDefault(require("../../hooks/useBackground"));
var _functions = require("../../theme/functions");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  iconStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.navbar-toggler': (0, _css.default)`
    padding: $navbar-toggler-padding-y $navbar-toggler-padding-x;
    background-color: transparent; // remove default button style
    border: $border-width solid transparent; // remove default button style
    border-radius: $navbar-toggler-border-radius;
    // @include transition($navbar-toggler-transition);

    &:focus {
      @include platform(web) {
        outline-width: 0; // outline: 0;
      }
      // box-shadow: 0 0 0 $navbar-toggler-focus-width;
    }
  `,
  '.navbar-toggler --text': (0, _css.default)`
    font-size: $navbar-toggler-font-size;
    line-height: $navbar-toggler-font-size * $line-height-base;

    &:hover {
      text-decoration: none;
    }

    &:focus {
      text-decoration: none;
    }
  `,
  '.navbar-toggler-icon': (0, _css.default)`
    // display: inline-block;
    width: $navbar-toggler-font-size * 1.5; // 1.5em;
    height: $navbar-toggler-font-size * 1.5; // 1.5em;
    // vertical-align: middle;
    background-repeat: no-repeat;
    background-position: center;
    background-size: 100%;
  `,
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.navbar-expand${(0, _breakpoints.infix)((0, _breakpoints.next)(breakpoint))} .navbar-toggler`]: (0, _css.default)`
      @include media-breakpoint-up(${(0, _breakpoints.next)(breakpoint)}) {
        display: none;
      }
    `
  })),
  '.navbar-light .navbar-toggler': (0, _css.default)`
    border-color: $navbar-light-toggler-border-color;
  `,
  '.navbar-light .navbar-toggler --text': (0, _css.default)`
    color: $navbar-light-color;
  `,
  '.navbar-light .navbar-toggler-icon': (0, _css.default)`
    background-image: ${t => (0, _functions.escapeSvg)(t['navbar-light-toggler-icon-bg'])};
  `,
  '.navbar-dark .navbar-toggler': (0, _css.default)`
    border-color: $navbar-dark-toggler-border-color;
  `,
  '.navbar-dark .navbar-toggler --text': (0, _css.default)`
    color: $navbar-dark-color;
  `,
  '.navbar-dark .navbar-toggler-icon': (0, _css.default)`
    background-image: ${t => (0, _functions.escapeSvg)(t['navbar-dark-toggler-icon-bg'])};
  `
});
const NavbarToggler = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    style,
    textStyle,
    iconStyle,
    ...elementProps
  } = props;
  const media = (0, _useMedia.default)();
  const {
    variant,
    expand
  } = (0, _useForcedContext.default)(_NavbarContext.default);
  const classes = (0, _utils.getStyles)(styles, ['.navbar-toggler', `.navbar-${variant} .navbar-toggler`, expand && `.navbar-expand${expand === true ? '' : `-${expand}`} .navbar-toggler`]);
  const textClasses = (0, _utils.getStyles)(styles, ['.navbar-toggler --text', `.navbar-${variant} .navbar-toggler --text`]);
  const iconClasses = (0, _utils.getStyles)(styles, ['.navbar-toggler-icon', `.navbar-${variant} .navbar-toggler-icon`]);
  const resolveIconStyle = (0, _useStyle.default)([iconClasses, iconStyle]);
  const background = (0, _useBackground.default)(resolveIconStyle({
    media
  }));
  return /*#__PURE__*/_react.default.createElement(_Pressable.default, _extends({}, elementProps, {
    ref: ref,
    toggle: _useToggleNavbar.default,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/_react.default.createElement(_View.default, {
    style: background.style
  }, background.element));
});
NavbarToggler.displayName = 'NavbarToggler';
NavbarToggler.propTypes = propTypes;
var _default = exports.default = NavbarToggler;
//# sourceMappingURL=NavbarToggler.js.map