"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.PLACEMENTS = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactNative = require("react-native");
var _overlays = require("@react-native-aria/overlays");
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _BackdropHandler = _interopRequireDefault(require("../helpers/BackdropHandler"));
var _View = _interopRequireDefault(require("../View"));
var _proxies = require("../../theme/proxies");
var _breakpoints = require("../../theme/breakpoints");
var _utils = require("../../utils");
var _useMedia = _interopRequireDefault(require("../../hooks/useMedia"));
var _useScrollbarEffects = _interopRequireDefault(require("../../hooks/useScrollbarEffects"));
var _NavbarContext = _interopRequireDefault(require("../navbar/NavbarContext"));
var _useOffcanvas = _interopRequireDefault(require("./useOffcanvas"));
var _OffcanvasContext = _interopRequireDefault(require("./OffcanvasContext"));
var _OffcanvasHeader = _interopRequireDefault(require("./OffcanvasHeader"));
var _OffcanvasTitle = _interopRequireDefault(require("./OffcanvasTitle"));
var _OffcanvasBody = _interopRequireDefault(require("./OffcanvasBody"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const PLACEMENTS = exports.PLACEMENTS = ['top', 'bottom', 'start', 'end']; // , 'auto'

const propTypes = {
  children: _propTypes.default.node.isRequired,
  visible: _propTypes.default.bool,
  placement: _propTypes.default.oneOf(PLACEMENTS),
  backdrop: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.oneOf(['static'])]),
  // Currently only supported on web.
  scroll: _propTypes.default.bool,
  onToggle: _propTypes.default.func,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogTextStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.offcanvas': (0, _css.default)`
    position: absolute; // fixed;
    // bottom: 0;
    z-index: $zindex-offcanvas;
    display: flex;
    flex-direction: column;
    max-width: 100%;
    // visibility: hidden;
    background-color: $offcanvas-bg-color;
    // background-clip: padding-box;
    @include platform(web) {
      outline-width: 0; // outline: 0;
    }
    // @include box-shadow($offcanvas-box-shadow);
    // @include transition(transform $offcanvas-transition-duration ease-in-out);
  `,
  '.offcanvas --text': (0, _css.default)`
    color: $offcanvas-color;
  `,
  '.offcanvas-backdrop': (0, _css.default)`
    position: absolute;
    top: 0;
    left: 0;
    z-index: $zindex-offcanvas-backdrop;
    width: 100%;
    height: 100%;
    background-color: $offcanvas-backdrop-bg;
    opacity: $offcanvas-backdrop-opacity;
  `,
  '.offcanvas-start': (0, _css.default)`
    top: 0;
    bottom: 0; // added for bootstrap-rn
    left: 0;
    // width: $offcanvas-horizontal-width;
    border-right-width: $offcanvas-border-width;
    border-style: solid;
    border-color: $offcanvas-border-color;
    // transform: translateX(-100%);
  `,
  '.offcanvas-end': (0, _css.default)`
    top: 0;
    bottom: 0; // added for bootstrap-rn
    right: 0;
    // width: $offcanvas-horizontal-width;
    border-left-width: $offcanvas-border-width;
    border-style: solid;
    border-color: $offcanvas-border-color;
    // transform: translateX(100%);
  `,
  '.offcanvas-top': (0, _css.default)`
    top: 0;
    right: 0;
    left: 0;
    // height: $offcanvas-vertical-height;
    max-height: 100%;
    border-bottom-width: $offcanvas-border-width;
    border-style: solid;
    border-color: $offcanvas-border-color;
    // transform: translateY(-100%);
  `,
  '.offcanvas-bottom': (0, _css.default)`
    bottom: 0; // added for bootstrap-rn
    right: 0;
    left: 0;
    // height: $offcanvas-vertical-height;
    max-height: 100%;
    width: 100%;
    border-top-width: $offcanvas-border-width;
    border-style: solid;
    border-color: $offcanvas-border-color;
    // transform: translateY(100%);
  `,
  // The following .offcanvas-dialog classes are added for bootstrap-rn,
  // because otherwise the text would exceed a width of 100% on native
  // and also additional width by SafeAreaView would not be applied.
  '.offcanvas-dialog': (0, _css.default)`
    max-width: 100%;
    max-height: 100%;
  `,
  '.offcanvas-dialog-start': (0, _css.default)`
    width: $offcanvas-horizontal-width;
  `,
  '.offcanvas-dialog-end': (0, _css.default)`
    width: $offcanvas-horizontal-width;
  `,
  '.offcanvas-dialog-top': (0, _css.default)`
    height: $offcanvas-vertical-height;
  `,
  '.offcanvas-dialog-bottom': (0, _css.default)`
    height: $offcanvas-vertical-height;
  `,
  // Navbar styles
  ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => ({
    [`.navbar-expand${(0, _breakpoints.infix)((0, _breakpoints.next)(breakpoint))} .offcanvas`]: (0, _css.default)`
      @include media-breakpoint-up(${(0, _breakpoints.next)(breakpoint)}) {
        position: relative; // inherit;
        bottom: 0;
        // z-index: auto;
        flex-grow: 1;
        // visibility: visible !important; // stylelint-disable-line declaration-no-important
        background-color: transparent;
        border-right-width: 0;
        border-left-width: 0;
        // @include box-shadow(none);
        // @include transition(none);
        // transform: none;
      }
    `
  }))
});
const Offcanvas = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    visible,
    placement = 'top',
    backdrop = true,
    scroll = false,
    onToggle: handleToggle,
    style,
    dialogStyle,
    textStyle,
    dialogTextStyle,
    ...elementProps
  } = props;
  const media = (0, _useMedia.default)();
  const navbar = (0, _react.useContext)(_NavbarContext.default);
  const offcanvasRef = (0, _react.useRef)();
  const offcanvas = (0, _useOffcanvas.default)();
  (0, _useScrollbarEffects.default)({
    keepBodyScroll: scroll,
    visible
  });
  const backdropClasses = (0, _utils.getStyles)(styles, ['.offcanvas-backdrop']);
  const classes = (0, _utils.getStyles)(styles, ['.offcanvas', `.offcanvas-${placement}`, navbar && navbar.expand && `.navbar-expand${navbar.expand === true ? '' : `-${navbar.expand}`} .offcanvas`]);
  const dialogClasses = (0, _utils.getStyles)(styles, ['.offcanvas-dialog', `.offcanvas-dialog-${placement}`]);
  const textClasses = (0, _utils.getStyles)(styles, ['.offcanvas-content --text']);

  // Render children without modal for navbar.
  if (navbar && navbar.expand && (navbar.expand === true || media.up(navbar.expand))) {
    return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    transparent: true,
    visible: navbar ? navbar.expanded : visible,
    onRequestClose: handleToggle
  }, placement !== 'bottom' && /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: {
      flexGrow: 0
    }
  }), /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: {
      flexGrow: 1
    }
  }, backdrop && /*#__PURE__*/_react.default.createElement(_View.default, {
    style: backdropClasses
  }, /*#__PURE__*/_react.default.createElement(_BackdropHandler.default, {
    dialogRef: offcanvasRef,
    onClose: handleToggle,
    backdrop: backdrop
  })), /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: (0, _utils.concatRefs)(offcanvasRef, ref),
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/_react.default.createElement(_View.default, {
    style: [dialogClasses, dialogStyle],
    textStyle: dialogTextStyle
  }, /*#__PURE__*/_react.default.createElement(_OffcanvasContext.default.Provider, {
    value: offcanvas
  }, /*#__PURE__*/_react.default.createElement(_overlays.OverlayProvider, null, children))))));
});
Offcanvas.displayName = 'Offcanvas';
Offcanvas.propTypes = propTypes;
Offcanvas.Context = _OffcanvasContext.default;
Offcanvas.Header = _OffcanvasHeader.default;
Offcanvas.Title = _OffcanvasTitle.default;
Offcanvas.Body = _OffcanvasBody.default;
var _default = exports.default = Offcanvas;
//# sourceMappingURL=Offcanvas.js.map