"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _Text = _interopRequireDefault(require("../Text"));
var _View = _interopRequireDefault(require("../View"));
var _utils = require("../../utils");
var _useForcedContext = _interopRequireDefault(require("../../hooks/useForcedContext"));
var _ProgressContext = _interopRequireDefault(require("./ProgressContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  children: _propTypes.default.node,
  value: _propTypes.default.number.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.progress-bar': (0, _css.default)`
    display: flex;
    flex-direction: column;
    justify-content: center;
    overflow: hidden;
    background-color: $progress-bar-bg;
    // @include transition($progress-bar-transition);
  `,
  '.progress-bar --text': (0, _css.default)`
    color: $progress-bar-color;
    text-align: center;
    // white-space: nowrap;
  `
});
const ROUND_PRECISION = 1000;
const getPercentage = (value, min, max) => {
  const percentage = (value - min) / (max - min) * 100;
  return Math.round(percentage * ROUND_PRECISION) / ROUND_PRECISION;
};
const ProgressBar = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    children,
    value,
    style,
    textStyle,
    ...elementProps
  } = props;
  const {
    min,
    max
  } = (0, _useForcedContext.default)(_ProgressContext.default);
  const classes = (0, _utils.getStyles)(styles, ['.progress-bar']);
  const textClasses = (0, _utils.getStyles)(styles, ['.progress-bar --text']);

  // composite component
  return /*#__PURE__*/_react.default.createElement(_View.default, _extends({}, elementProps, {
    ref: ref,
    role: "progressbar",
    "aria-valuenow": value,
    "aria-valuemin": min,
    "aria-valuemax": max,
    style: [classes, style, {
      width: `${getPercentage(value, min, max)}%`
    }]
  }), children && /*#__PURE__*/_react.default.createElement(_Text.default, {
    style: [textClasses, textStyle]
  }, children));
});
ProgressBar.displayName = 'ProgressBar';
ProgressBar.propTypes = propTypes;
var _default = exports.default = ProgressBar;
//# sourceMappingURL=ProgressBar.js.map