"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _StyleSheet = _interopRequireDefault(require("../../style/StyleSheet"));
var _css = _interopRequireDefault(require("../../style/css"));
var _View = _interopRequireDefault(require("../View"));
var _proxies = require("../../theme/proxies");
var _utils = require("../../utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const propTypes = {
  variant: _propTypes.default.oneOf(['border', 'grow']),
  color: _propTypes.default.oneOf(Object.keys(_proxies.THEME_COLORS)),
  size: _propTypes.default.oneOf(['sm']),
  // eslint-disable-next-line react/forbid-prop-types
  style: _propTypes.default.any
};
const styles = _StyleSheet.default.create({
  '.spinner-border': (0, _css.default)`
    // display: inline-block;
    width: $spinner-width;
    height: $spinner-height;
    // vertical-align: $spinner-vertical-align;
    border-width: $spinner-border-width;
    border-style: solid;
    border-top-color: $body-color;
    border-bottom-color: $body-color;
    border-left-color: $body-color;
    // workaround for issue https://github.com/facebook/react-native/issues/34722
    border-right-color: rgba(0, 0, 0, 0.01); // transparent;
    border-radius: $spinner-width * 50%;
    // animation: $spinner-animation-speed linear infinite spinner-border;
  `,
  ...(0, _utils.each)(_proxies.THEME_COLORS, (color, value) => ({
    [`.spinner-border-${color}`]: (0, _css.default)`
      border-top-color: ${value};
      border-bottom-color: ${value};
      border-left-color: ${value};
    `
  })),
  '.spinner-border-sm': (0, _css.default)`
    width: $spinner-width-sm;
    height: $spinner-height-sm;
    border-width: $spinner-border-width-sm;
  `,
  '.spinner-grow': (0, _css.default)`
    // display: inline-block;
    width: $spinner-width;
    height: $spinner-height;
    // vertical-align: $spinner-vertical-align;
    background-color: $body-color;
    border-radius: $spinner-width * 50%;
    opacity: 0;
    // animation: $spinner-animation-speed linear infinite spinner-grow;
  `,
  ...(0, _utils.each)(_proxies.THEME_COLORS, (color, value) => ({
    [`.spinner-grow-${color}`]: (0, _css.default)`
      background-color: ${value};
    `
  })),
  '.spinner-grow-sm': (0, _css.default)`
    width: $spinner-width-sm;
    height: $spinner-height-sm;
  `
});
const AnimatedView = _reactNative.Animated.createAnimatedComponent(_View.default);
const getAnimationStyle = (variant, animation) => {
  switch (variant) {
    case 'border':
      return {
        transform: _reactNative.Platform.OS === 'web' ? animation.interpolate({
          inputRange: [0, 1],
          outputRange: ['rotate(0deg)', 'rotate(360deg)']
        }) : [{
          rotate: animation.interpolate({
            inputRange: [0, 1],
            outputRange: ['0deg', '360deg']
          })
        }]
      };
    case 'grow':
      return {
        transform: _reactNative.Platform.OS === 'web' ? animation.interpolate({
          inputRange: [0, 0.5, 1],
          outputRange: ['scale(0)', 'scale(1)', 'scale(1)']
        }) : [{
          scale: animation.interpolate({
            inputRange: [0, 0.5, 1],
            outputRange: [0, 1, 1]
          })
        }],
        opacity: animation.interpolate({
          inputRange: [0, 0.5, 1],
          outputRange: [0, 1, 0]
        })
      };
    default:
      throw new Error('Unknown spinner variant.');
  }
};
const Spinner = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    variant = 'border',
    color,
    size,
    style,
    ...elementProps
  } = props;
  const classes = (0, _utils.getStyles)(styles, [`.spinner-${variant}`, color && `.spinner-${variant}-${color}`, size === 'sm' && `.spinner-${variant}-sm`]);
  const role = _reactNative.Platform.OS === 'web' ? 'status' : null;
  const animation = (0, _react.useMemo)(() => new _reactNative.Animated.Value(0), []);
  (0, _react.useEffect)(() => {
    const duration = parseFloat(_StyleSheet.default.value('spinner-animation-speed')) * 1000;
    _reactNative.Animated.loop(_reactNative.Animated.timing(animation, {
      toValue: 1,
      duration,
      easing: _reactNative.Easing.linear,
      useNativeDriver: _reactNative.Platform.OS !== 'web'
    })).start();
  }, []);
  return /*#__PURE__*/_react.default.createElement(AnimatedView, _extends({}, elementProps, {
    ref: ref,
    role: role,
    "aria-hidden": true,
    style: [classes, getAnimationStyle(variant, animation), style]
  }));
});
Spinner.displayName = 'Spinner';
Spinner.propTypes = propTypes;
var _default = exports.default = Spinner;
//# sourceMappingURL=Spinner.js.map