"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useControlledState;
var _react = require("react");
function useControlledState(defaultValue, controlledValue) {
  let handleChange = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : () => {};
  const [stateValue, setStateValue] = (0, _react.useState)(defaultValue);
  const isControlled = controlledValue !== undefined && controlledValue !== null;
  const value = isControlled ? controlledValue : stateValue;
  const setValue = next => {
    const nextValue = typeof next === 'function' ? next(value) : next;
    if (value === nextValue) {
      return;
    }
    if (!isControlled) {
      setStateValue(next);
    }
    handleChange(nextValue);
  };
  return [value, setValue];
}
//# sourceMappingURL=useControlledState.js.map