"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useInteractionState;
var _react = require("react");
var _focus = require("@react-native-aria/focus");
function useInteractionState(_ref) {
  let {
    onFocus = () => {},
    onBlur = () => {},
    onHoverIn = () => {},
    onHoverOut = () => {},
    onPressIn = () => {},
    onPressOut = () => {},
    autoFocus
  } = _ref;
  const [active, setActive] = (0, _react.useState)(false);
  const [hover, setHovered] = (0, _react.useState)(false);
  const {
    isFocused: focus,
    isFocusVisible: focusVisible,
    focusProps
  } = (0, _focus.useFocusRing)({
    autoFocus
  });
  const interactionProps = (0, _react.useMemo)(() => ({
    onHoverIn(event) {
      setHovered(true);
      onHoverIn(event);
    },
    onHoverOut(event) {
      setHovered(false);
      onHoverOut(event);
    },
    onFocus(event) {
      focusProps.onFocus(event);
      onFocus(event);
    },
    onBlur(event) {
      focusProps.onBlur(event);
      onBlur(event);
    },
    onPressIn(event) {
      setActive(true);
      onPressIn(event);
    },
    onPressOut(event) {
      setActive(false);
      onPressOut(event);
    }
  }), [onFocus, onBlur, onHoverIn, onHoverOut, onPressIn, onPressOut]);
  const interaction = {
    hover,
    focus,
    focusVisible,
    active
  };
  return {
    interaction,
    interactionProps
  };
}
//# sourceMappingURL=useInteractionState.js.map