"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useScrollbarEffects;
var _react = require("react");
var _reactNative = require("react-native");
var _Context = _interopRequireDefault(require("../Context"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const computeScrollbarWidth = () => {
  const documentWidth = document.documentElement.clientWidth;
  return Math.abs(window.innerWidth - documentWidth);
};
function useScrollbarEffects(_ref) {
  let {
    keepBodyScroll,
    visible
  } = _ref;
  if (_reactNative.Platform.OS !== 'web' || keepBodyScroll) {
    return;
  }
  const context = (0, _react.useContext)(_Context.default);
  const scrollbarWidth = (0, _react.useRef)();
  (0, _react.useEffect)(() => {
    if (!visible) {
      return undefined;
    }
    if (!scrollbarWidth.current) {
      scrollbarWidth.current = computeScrollbarWidth();
    }
    const rect = document.body.getBoundingClientRect();
    const isBodyOverflowing = rect.left + rect.right < window.innerWidth;

    // Set body and fixed elements padding adjustments.
    const fixedElements = context.fixed.filter(ref => ref.current).map(ref => (0, _reactNative.findNodeHandle)(ref.current));
    const elements = [document.body, ...fixedElements];
    const originalWidths = elements.map(el => el.style.width || '');
    const originalBodyOverflow = document.body.style.overflow || '';
    if (isBodyOverflowing) {
      elements.forEach(el => {
        // eslint-disable-next-line no-param-reassign
        el.style.width = `calc(100% - ${scrollbarWidth.current}px)`;
      });
    }

    // Add "overflow: hidden" to body element.
    document.body.style.overflow = 'hidden';
    return () => {
      // Reset body padding adjustments.
      elements.forEach((el, key) => {
        // eslint-disable-next-line no-param-reassign
        el.style.width = originalWidths[key] || '';
      });

      // Remove "overflow: hidden" from body element.
      document.body.style.overflow = originalBodyOverflow;
    };
  }, [visible]);
}
//# sourceMappingURL=useScrollbarEffects.js.map