"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useStyle;
var _react = require("react");
var _createStyle = require("../style/createStyle");
var _Context = _interopRequireDefault(require("../Context"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const normalize = style => {
  if (!Array.isArray(style)) {
    return [style];
  }
  return style.filter(val => !!val).reduce((res, val) => [...res, ...normalize(val)], []);
};
function useStyle(style, styleName) {
  const {
    utilities: utilitiesStyles
  } = (0, _react.useContext)(_Context.default);
  const utilities = (0, _react.useMemo)(() => {
    if (!styleName) {
      return null;
    }
    const names = styleName.split(' ');
    return names.map(name => {
      if (!utilitiesStyles[name]) {
        // eslint-disable-next-line no-console
        console.warn(`Unknown utility style "${name}".`);
        return null;
      }
      return utilitiesStyles[name];
    });
  }, [styleName]);
  const styles = normalize(utilities ? [style, ...utilities] : style);
  return state => {
    const basicStyles = [];
    const interactionStyles = [];
    styles.forEach(value => {
      if (value && value.$$typeof === _createStyle.BOOTSTRAP_RN_STYLE) {
        // Style is a bootstrap style that contains basic and interaction styles.
        const [resolvedBasicStyles, resolvedInteractionStyles] = value(state);
        basicStyles.push(...resolvedBasicStyles);
        interactionStyles.push(...resolvedInteractionStyles);
      } else if (typeof value === 'function') {
        // Style is some other custom function type style.
        basicStyles.push(value(state));
      } else {
        // Style is basic object style.
        basicStyles.push(value);
      }
    });

    // Put basic styles first, then interaction styles for hover, focus, pressed.
    return [...basicStyles, ...interactionStyles];
  };
}
//# sourceMappingURL=useStyle.js.map