"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TriggerPropTypes = void 0;
exports.default = useTrigger;
var _react = require("react");
var _reactNative = require("react-native");
var _propTypes = _interopRequireDefault(require("prop-types"));
var _useIdentifier = _interopRequireDefault(require("./useIdentifier"));
var _utils = require("../utils");
var _useControlledState = _interopRequireDefault(require("./useControlledState"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const PLACEMENTS = ['top', 'bottom', 'left', 'right'];
const TRIGGERS = ['press', 'hover', 'focus', 'manual', 'press hover', 'hover press', 'hover focus', 'focus hover', 'press focus', 'focus press'];
const TriggerPropTypes = exports.TriggerPropTypes = {
  trigger: _propTypes.default.oneOf(TRIGGERS),
  placement: _propTypes.default.oneOf(PLACEMENTS),
  offset: _propTypes.default.number,
  defaultVisible: _propTypes.default.bool,
  visible: _propTypes.default.bool,
  onToggle: _propTypes.default.func
};
function useTrigger(rawTrigger, props, elementProps, ref) {
  const {
    defaultVisible = false,
    visible: controlledVisible,
    onToggle
  } = props;
  const {
    onPress,
    onFocus,
    onBlur,
    onMouseOver,
    onMouseLeave
  } = elementProps;
  const trigger = rawTrigger.split(' ');
  const identifier = (0, _useIdentifier.default)('overlay');
  const [visible, setVisible] = (0, _useControlledState.default)(defaultVisible, controlledVisible, onToggle);
  const [focused, setFocused] = (0, _react.useState)(false);
  const [hovered, setHovered] = (0, _react.useState)(false);
  const targetRef = (0, _react.useRef)();
  return {
    visible,
    setVisible,
    targetProps: {
      ref: (0, _utils.concatRefs)(targetRef, ref),
      ...(0, _utils.optional)(visible, {
        'aria-describedby': identifier
      }),
      onPress: event => {
        const handleHoverAsPress = (_reactNative.Platform.OS === 'android' || _reactNative.Platform.OS === 'ios') && trigger.includes('hover');
        if (trigger.includes('press') || handleHoverAsPress) {
          setVisible(value => !value);
        }
        if (onPress) {
          onPress(event);
        }
      },
      onFocus: event => {
        if (trigger.includes('focus')) {
          setFocused(true);
          if (!visible) {
            setVisible(true);
          }
        }
        if (onFocus) {
          onFocus(event);
        }
      },
      onBlur: event => {
        if (trigger.includes('focus')) {
          setFocused(false);
          const activeHoverTrigger = trigger.includes('hover') && hovered;
          if (visible && !activeHoverTrigger) {
            setVisible(false);
          }
        }
        if (onBlur) {
          onBlur(event);
        }
      },
      onMouseOver: event => {
        if (trigger.includes('hover')) {
          setHovered(true);
          if (!visible && !focused) {
            setVisible(true);
          }
        }
        if (onMouseOver) {
          onMouseOver(event);
        }
      },
      onMouseLeave: event => {
        if (trigger.includes('hover')) {
          setHovered(false);
          const activeFocusTrigger = trigger.includes('focus') && focused;
          if (visible && !activeFocusTrigger) {
            setVisible(false);
          }
        }
        if (onMouseLeave) {
          onMouseLeave(event);
        }
      }
    },
    targetRef,
    templateProps: {
      id: identifier
    }
  };
}
//# sourceMappingURL=useTrigger.js.map