"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useViewport;
var _react = require("react");
var _reactNative = require("react-native");
var _StyleSheet = _interopRequireDefault(require("../style/StyleSheet"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const calculateViewport = (breakpoints, width) => {
  if (width < breakpoints.sm) {
    return 'xs';
  }
  if (width < breakpoints.md) {
    return 'sm';
  }
  if (width < breakpoints.lg) {
    return 'md';
  }
  if (width < breakpoints.xl) {
    return 'lg';
  }
  if (width < breakpoints.xxl) {
    return 'xl';
  }
  return 'xxl';
};
const getWidth = dimensions => {
  // Use web api on web because of issue #38:
  // https://github.com/examunity/bootstrap-rn/issues/38
  if (_reactNative.Platform.OS === 'web') {
    return Math.max(document.documentElement.clientWidth || 0, window.innerWidth || 0);
  }
  return dimensions.window.width;
};
function useViewport(initialViewport) {
  const [viewport, setViewport] = (0, _react.useState)(initialViewport);
  const breakpoints = _StyleSheet.default.value('grid-breakpoints');
  const handleChange = dimensions => {
    const width = getWidth(dimensions);
    const nextViewport = calculateViewport(breakpoints, width);
    setViewport(nextViewport);
  };
  (0, _react.useEffect)(() => {
    // Initially determine viewport after mounting.
    handleChange({
      window: _reactNative.Dimensions.get('window')
    });
    const subscription = _reactNative.Dimensions.addEventListener('change', handleChange);
    return () => {
      subscription.remove();
    };
  }, []);
  return viewport;
}
//# sourceMappingURL=useViewport.js.map