"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.BOOTSTRAP_RN_STYLE = void 0;
var _reactNative = require("react-native");
var _mediaBreakpointBetween = _interopRequireDefault(require("./mixins/mediaBreakpointBetween"));
var _mediaBreakpointDown = _interopRequireDefault(require("./mixins/mediaBreakpointDown"));
var _mediaBreakpointOnly = _interopRequireDefault(require("./mixins/mediaBreakpointOnly"));
var _mediaBreakpointUp = _interopRequireDefault(require("./mixins/mediaBreakpointUp"));
var _platform = _interopRequireDefault(require("./mixins/platform"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const BOOTSTRAP_RN_STYLE = exports.BOOTSTRAP_RN_STYLE = Symbol.for('bootstrap-rn.style');
const mixins = {
  'media-breakpoint-between': _mediaBreakpointBetween.default,
  'media-breakpoint-down': _mediaBreakpointDown.default,
  'media-breakpoint-only': _mediaBreakpointOnly.default,
  'media-breakpoint-up': _mediaBreakpointUp.default,
  platform: _platform.default
};
const hasInteraction = _ref => {
  let {
    scopes
  } = _ref;
  return scopes.some(scope => scope.type === 'selector');
};
function createStyle(definitions) {
  // If there is only one definition without conditions, return.
  if (definitions.length === 1 && definitions[0].scopes.length === 0) {
    return definitions[0].declarations;
  }

  // Filter definitions that should not be used based on mixins.
  const platformDefinitions = definitions.filter(item => item.scopes.every(scope => {
    if (scope.type !== 'mixin') {
      return true;
    }
    return mixins[scope.name].include(scope);
  }));

  // Create style sheets.
  const styles = _reactNative.StyleSheet.create({
    ...platformDefinitions.map(item => item.declarations)
  });
  const resolve = state => {
    const {
      interaction
    } = state;
    const basicStyles = [];
    const interactionStyles = [];
    Object.values(styles).forEach((style, key) => {
      const active = platformDefinitions[key].scopes.every(scope => {
        if (scope.type === 'selector') {
          if (scope.name === 'hover') {
            return interaction && interaction.hover;
          }
          if (scope.name === 'focus') {
            return interaction && interaction.focus;
          }
          if (scope.name === 'focus-visible') {
            return interaction && interaction.focusVisible;
          }
          if (scope.name === 'active') {
            return interaction && interaction.active;
          }
        }
        if (scope.type === 'mixin') {
          return mixins[scope.name].apply(scope, state);
        }
        throw new Error(`Unknown scope type "${scope.type}"`);
      });
      if (active) {
        if (hasInteraction(platformDefinitions[key])) {
          interactionStyles.push(style);
        } else {
          basicStyles.push(style);
        }
      }
    });
    return [basicStyles, interactionStyles];
  };
  resolve.$$typeof = BOOTSTRAP_RN_STYLE;
  return resolve;
}
var _default = exports.default = createStyle;
//# sourceMappingURL=createStyle.js.map