"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mix = mix;
exports.opacity = opacity;
exports.rgb = rgb;
exports.rgba = rgba;
var _RgbaValue = _interopRequireDefault(require("./types/RgbaValue"));
var _UnitValue = _interopRequireDefault(require("./types/UnitValue"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// Sass equivalent
function rgb(value) {
  const color = _RgbaValue.default.parse(value);
  return `rgb(${color.red},${color.green},${color.blue})`;
}

// Sass equivalent
function rgba(value, alpha) {
  const color = _RgbaValue.default.parse(value);
  return `rgba(${color.red},${color.green},${color.blue},${alpha})`;
}

// Sass equivalent
function opacity(value) {
  return _RgbaValue.default.parse(value).alpha;
}

// Sass equivalent
function mix(color1, color2) {
  let weight = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0.5;
  const rgb1 = _RgbaValue.default.parse(color1).toRgb();
  const rgb2 = _RgbaValue.default.parse(color2).toRgb();
  const percentage = _UnitValue.default.parse(weight).toNumber();
  const [r, g, b] = rgb1.map((value, key) => Math.round(rgb2[key] + (value - rgb2[key]) * percentage));
  return new _RgbaValue.default(r, g, b).toHex();
}
//# sourceMappingURL=functions.js.map