"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = makeUtilities;
exports.makeUtility = makeUtility;
var _css = _interopRequireDefault(require("./css"));
var _proxies = require("../theme/proxies");
var _utilities = _interopRequireDefault(require("../theme/utilities"));
var _utils = require("../utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function makeUtility(options) {
  return (0, _utils.each)(options.values, (key, value) => {
    const name = options.class || options.property;
    const suffix = key === 'null' ? '' : `-${key}`;
    const styles = {
      [`${name}${suffix}`]: (0, _css.default)`
        ${options.property}: ${value};
      `
    };
    if (!options.responsive) {
      return styles;
    }
    return {
      ...styles,
      ...(0, _utils.each)(_proxies.GRID_BREAKPOINTS, breakpoint => {
        if (breakpoint === 'xs') {
          return null;
        }
        return {
          [`${name}-${breakpoint}${suffix}`]: (0, _css.default)`
            @include media-breakpoint-up(${breakpoint}) {
              ${options.property}: ${value};
            }
          `
        };
      })
    };
  });
}
function makeUtilities(resolve) {
  const customUtilities = typeof resolve === 'function' ? resolve(_utilities.default) : resolve;
  const definitions = Object.values({
    ..._utilities.default,
    ...customUtilities
  }).reduce((result, utility) => {
    if (!utility) {
      return result;
    }
    return Object.assign(result, makeUtility(utility));
  }, {});
  return definitions;
}
//# sourceMappingURL=makeUtilities.js.map