"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
const checkFunction = (char, silent) => {
  if (typeof char !== 'function') {
    return true;
  }
  if (silent) {
    return false;
  }
  throw new Error(`CSS syntax error: Unexpected function.`);
};
class InputStream {
  constructor(fragments) {
    for (var _len = arguments.length, tags = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      tags[_key - 1] = arguments[_key];
    }
    this.dictionary = fragments.reduce((result, current, i) => {
      const value = current.split('');
      const tag = tags[i - 1];
      if (!tag) {
        return [...result, ...value];
      }
      if (typeof tag !== 'string') {
        return [...result, tag, ...value];
      }
      return [...result, ...tag.split(''), ...value];
    });
    this.cursor = 0;
  }
  peek() {
    let offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return this.dictionary[this.cursor + offset];
  }
  read(marker) {
    const char = this.peek();
    if (marker && marker !== char) {
      throw new Error(`CSS syntax error: Expected "${marker}", but found "${char}"`);
    }
    if (this.remainingChars() === 0) {
      throw new Error(`CSS syntax error: Unexpected end of string.`);
    }
    this.cursor += 1;
    return char;
  }
  charsWhile(check) {
    let silent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    let value = '';
    while (checkFunction(this.peek(), silent) && check(this.peek())) {
      value += this.read();
    }
    return value;
  }
  remainingChars() {
    return this.dictionary.length - this.cursor;
  }
}
var _default = exports.default = InputStream;
//# sourceMappingURL=InputStream.js.map