"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _isIdent = _interopRequireDefault(require("../isIdent"));
var _isWhitespace = _interopRequireDefault(require("../isWhitespace"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const breaksDeclaration = char => typeof char !== 'function' && char !== '$' && char !== ';' && char !== '}' &&
// char !== '(' &&
char !== '';
const declaration = {
  locate(input) {
    return /[a-z_]/i.test(input.peek());
  },
  read(input) {
    // Parse name.
    const name = input.charsWhile(_isIdent.default);

    // Parse whitespaces, separator
    input.charsWhile(_isWhitespace.default);
    input.read(':');
    input.charsWhile(_isWhitespace.default, true);

    // Parse value.
    const value = [];
    do {
      // Add function to resolve variable.
      if (input.peek() === '$') {
        input.read('$');
        const variableName = input.charsWhile(_isIdent.default);
        value.push(variables => {
          if (variables[variableName] === undefined) {
            throw new Error(`Variable $${variableName} is not defined.`);
          }
          return variables[variableName];
        });
      }

      // Add function.
      if (typeof input.peek() === 'function') {
        value.push(input.read());
      }
      const part = input.charsWhile(breaksDeclaration, true);

      // TODO: Parse functions
      /* if (input.peek() === '(') {
        } */

      if (part.length > 0) {
        value.push(part);
      }
    } while (input.peek() === '$' || typeof input.peek() === 'function');
    if (input.peek() === ';') {
      input.read(';');
    }
    return {
      type: 'declaration',
      name,
      value
    };
  }
};
var _default = exports.default = declaration;
//# sourceMappingURL=declaration.js.map