"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _reactNative = require("react-native");
const valueRE = /^([+-]?(?:\d+|\d*\.\d+))(rem|px|%)?$/;
class UnitValue {
  constructor(value) {
    let unit = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'number';
    this.value = value;
    this.unit = unit;
  }
  static parse(value) {
    if (value instanceof UnitValue) {
      return value;
    }
    if (typeof value === 'number') {
      return new UnitValue(value, 'number');
    }
    const match = value.match(valueRE);
    if (!match) {
      throw new Error(`Cannot parse number "${value}".`);
    }
    return new UnitValue(parseFloat(match[1]), match[2] === '%' ? 'percent' : match[2]);
  }
  toNumber() {
    if (this.unit === 'percent') {
      return this.value / 100;
    }
    if (this.unit === 'rem') {
      return this.value * _reactNative.PixelRatio.getFontScale() * 16;
    }
    return this.value;
  }
  toString() {
    if (this.unit === 'number') {
      return this.value;
    }
    if (this.unit === 'percent') {
      return `${this.value}%`;
    }
    return `${this.value}${this.unit}`;
  }
}
exports.default = UnitValue;
//# sourceMappingURL=UnitValue.js.map