function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import StyleSheet from '../../../style/StyleSheet';
import css from '../../../style/css';
import Pressable from '../../Pressable';
import Text from '../../Text';
import Offcanvas from '../../offcanvas/Offcanvas';
import useBackground from '../../../hooks/useBackground';
import PickerNativeContext from './PickerNativeContext';
const propTypes = {
  children: PropTypes.node.isRequired,
  selectedValue: PropTypes.oneOfType([PropTypes.bool, PropTypes.number, PropTypes.string, PropTypes.object]),
  onValueChange: PropTypes.func,
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
  placeholder: PropTypes.string,
  placeholderTextColor: PropTypes.string,
  disabled: PropTypes.bool,
  MenuComponent: PropTypes.elementType,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes.any
};
const styles = StyleSheet.create({
  menu: css`
    align-items: center;
  `
});

// Ref: https://reactnative.dev/docs/text-style-props
const textStyleKeys = ['color', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'includeFontPaddingAndroid', 'fontVariant', 'letterSpacing', 'lineHeight', 'textAlign', 'textAlignVerticalAndroid', 'textDecorationColoriOS', 'textDecorationLine', 'textDecorationStyleiOS', 'textShadowColor', 'textShadowOffset', 'textShadowRadius', 'textTransform', 'writingDirection'];
const extractTextStyles = style => {
  const textStyles = {};
  Object.entries(style).forEach(_ref => {
    let [key, value] = _ref;
    if (textStyleKeys.includes(key)) {
      textStyles[key] = value;
    }
  });
  return textStyles;
};
const getText = _ref2 => {
  let {
    children,
    selectedValue
  } = _ref2;
  const items = React.Children.map(children, child => ({
    label: child.props.label,
    value: child.props.value
  }));
  const selectedItem = items.find(item => item.value === selectedValue);
  return selectedItem?.label;
};

/* eslint-disable react/prop-types */
const DefaultMenuComponent = _ref3 => {
  let {
    children,
    selectedValue,
    onValueChange: handleValueChange,
    onClose: handleClose
  } = _ref3;
  return /*#__PURE__*/React.createElement(Offcanvas, {
    placement: "bottom",
    visible: true,
    onToggle: handleClose
  }, /*#__PURE__*/React.createElement(Offcanvas.Body, {
    contentContainerStyle: styles.menu
  }, /*#__PURE__*/React.createElement(PickerNativeContext.Provider, {
    value: {
      selectedValue,
      handleValueChange
    }
  }, children)));
};
/* eslint-enable */

const PickerNative = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    children,
    selectedValue,
    onValueChange = () => {},
    onFocus = () => {},
    onBlur = () => {},
    placeholder,
    placeholderTextColor,
    disabled = false,
    MenuComponent = DefaultMenuComponent,
    style,
    ...elementProps
  } = props;
  const background = useBackground(style);
  const [visible, setVisible] = useState(false);
  const textStyle = extractTextStyles(background.style);
  const showPlaceholder = selectedValue === undefined || selectedValue === null;
  const handleValueChange = nextValue => {
    onValueChange(nextValue);
    setVisible(false);
  };
  const handleClose = () => {
    setVisible(false);
  };
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Pressable, _extends({}, elementProps, {
    ref: ref,
    role: "combobox",
    onPress: () => {
      setVisible(true);
    },
    onFocus: onFocus,
    onBlur: onBlur,
    disabled: disabled,
    style: background.style
  }), background.element, /*#__PURE__*/React.createElement(Text, {
    numberOfLines: 1,
    style: [textStyle, showPlaceholder && {
      color: placeholderTextColor
    }]
  }, showPlaceholder ? placeholder || /*#__PURE__*/React.createElement(Text, null, "\xA0") : getText({
    children,
    selectedValue
  }))), visible && /*#__PURE__*/React.createElement(MenuComponent, {
    selectedValue: selectedValue,
    onValueChange: handleValueChange,
    onClose: handleClose
  }, children));
});
PickerNative.propTypes = propTypes;
export default PickerNative;
//# sourceMappingURL=PickerNative.js.map