import React from 'react';
import PropTypes from 'prop-types';
import StyleSheet from '../../style/StyleSheet';
import css from '../../style/css';
import Heading from '../Heading';
import { DISPLAY_FONT_SIZES } from '../../theme/proxies';
import { getStyles, each } from '../../utils';

const propTypes = {
  children: PropTypes.node.isRequired,
  size: PropTypes.oneOf(Object.keys(DISPLAY_FONT_SIZES).map((k) => Number(k)))
    .isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes.any,
};

const styles = StyleSheet.create({
  ...each(DISPLAY_FONT_SIZES, (size, value) => ({
    [`.display-${size}`]: css`
      font-size: ${value};
      line-height: ${value} * $headings-line-height;
    `,
  })),
});

const DisplayHeading = React.forwardRef((props, ref) => {
  const { children, size, style, ...elementProps } = props;

  const classes = getStyles(styles, [`.display-${size}`]);

  return (
    <Heading {...elementProps} ref={ref} size={1} style={[classes, style]}>
      {children}
    </Heading>
  );
});

DisplayHeading.displayName = 'Heading';
DisplayHeading.propTypes = propTypes;

export default DisplayHeading;
